# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

import typing

from pydantic import Field

from .bot_info import BotInfo
from .chat_photo import ChatPhoto
from ..base_object import BaseObject


class UserFullInfo(BaseObject):
    """
    Contains full information about a user
    
    Params:
        photo (:class:`ChatPhoto`)
            User profile photo; may be null
        
        is_blocked (:class:`bool`)
            True, if the user is blocked by the current user
        
        can_be_called (:class:`bool`)
            True, if the user can be called
        
        supports_video_calls (:class:`bool`)
            True, if a video call can be created with the user
        
        has_private_calls (:class:`bool`)
            True, if the user can't be called due to their privacy settings
        
        need_phone_number_privacy_exception (:class:`bool`)
            True, if the current user needs to explicitly allow to share their phone number with the user when the method addContact is used
        
        bio (:class:`str`)
            A short user bio
        
        share_text (:class:`str`)
            For bots, the text that is included with the link when users share the bot
        
        group_in_common_count (:class:`int`)
            Number of group chats where both the other user and the current user are a member; 0 for the current user
        
        bot_info (:class:`BotInfo`)
            If the user is a bot, information about the bot; may be null
        
    """

    ID: str = Field("userFullInfo", alias="@type")
    photo: typing.Optional[ChatPhoto] = None
    is_blocked: bool
    can_be_called: bool
    supports_video_calls: bool
    has_private_calls: bool
    need_phone_number_privacy_exception: bool
    bio: str
    share_text: str
    group_in_common_count: int
    bot_info: typing.Optional[BotInfo] = None

    @staticmethod
    def read(q: dict) -> UserFullInfo:
        return UserFullInfo.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from .passport_suitable_element import PassportSuitableElement
from ..base_object import BaseObject


class PassportRequiredElement(BaseObject):
    """
    Contains a description of the required Telegram Passport element that was requested by a service
    
    Params:
        suitable_elements (:obj:`list[PassportSuitableElement]`)
            List of Telegram Passport elements any of which is enough to provide
        
    """

    ID: str = Field("passportRequiredElement", alias="@type")
    suitable_elements: list[PassportSuitableElement]

    @staticmethod
    def read(q: dict) -> PassportRequiredElement:
        return PassportRequiredElement.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

import typing

from pydantic import Field

from .file import File
from .minithumbnail import Minithumbnail
from .thumbnail import Thumbnail
from ..base_object import BaseObject


class Video(BaseObject):
    """
    Describes a video file
    
    Params:
        duration (:class:`int`)
            Duration of the video, in seconds; as defined by the sender
        
        width (:class:`int`)
            Video width; as defined by the sender
        
        height (:class:`int`)
            Video height; as defined by the sender
        
        file_name (:class:`str`)
            Original name of the file; as defined by the sender
        
        mime_type (:class:`str`)
            MIME type of the file; as defined by the sender
        
        has_stickers (:class:`bool`)
            True, if stickers were added to the video. The list of corresponding sticker sets can be received using getAttachedStickerSets
        
        supports_streaming (:class:`bool`)
            True, if the video should be tried to be streamed
        
        minithumbnail (:class:`Minithumbnail`)
            Video minithumbnail; may be null
        
        thumbnail (:class:`Thumbnail`)
            Video thumbnail in JPEG or MPEG4 format; as defined by the sender; may be null
        
        video (:class:`File`)
            File containing the video
        
    """

    ID: str = Field("video", alias="@type")
    duration: int
    width: int
    height: int
    file_name: str
    mime_type: str
    has_stickers: bool
    supports_streaming: bool
    minithumbnail: typing.Optional[Minithumbnail] = None
    thumbnail: typing.Optional[Thumbnail] = None
    video: File

    @staticmethod
    def read(q: dict) -> Video:
        return Video.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject
from ..types import CallProtocol


class CreateCall(BaseObject):
    """
    Creates a new call
    
    Params:
        user_id (:class:`int`)
            Identifier of the user to be called
        
        protocol (:class:`CallProtocol`)
            Description of the call protocols supported by the application
        
        is_video (:class:`bool`)
            True, if a video call needs to be created
        
    """

    ID: str = Field("createCall", alias="@type")
    user_id: int
    protocol: CallProtocol
    is_video: bool

    @staticmethod
    def read(q: dict) -> CreateCall:
        return CreateCall.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class ToggleChatIsMarkedAsUnread(BaseObject):
    """
    Changes the marked as unread state of a chat
    
    Params:
        chat_id (:class:`int`)
            Chat identifier
        
        is_marked_as_unread (:class:`bool`)
            New value of is_marked_as_unread
        
    """

    ID: str = Field("toggleChatIsMarkedAsUnread", alias="@type")
    chat_id: int
    is_marked_as_unread: bool

    @staticmethod
    def read(q: dict) -> ToggleChatIsMarkedAsUnread:
        return ToggleChatIsMarkedAsUnread.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

import typing

from pydantic import Field

from .email_address_authentication_code_info import EmailAddressAuthenticationCodeInfo
from ..base_object import BaseObject


class PasswordState(BaseObject):
    """
    Represents the current state of 2-step verification
    
    Params:
        has_password (:class:`bool`)
            True, if a 2-step verification password is set
        
        password_hint (:class:`str`)
            Hint for the password; may be empty
        
        has_recovery_email_address (:class:`bool`)
            True, if a recovery email is set
        
        has_passport_data (:class:`bool`)
            True, if some Telegram Passport elements were saved
        
        recovery_email_address_code_info (:class:`EmailAddressAuthenticationCodeInfo`)
            Information about the recovery email address to which the confirmation email was sent; may be null
        
    """

    ID: str = Field("passwordState", alias="@type")
    has_password: bool
    password_hint: str
    has_recovery_email_address: bool
    has_passport_data: bool
    recovery_email_address_code_info: typing.Optional[EmailAddressAuthenticationCodeInfo] = None

    @staticmethod
    def read(q: dict) -> PasswordState:
        return PasswordState.construct(**q)



__version__ = "0.4.0"

from .client import Client, ClientProxySettings, ClientProxyType
from .filters import FilterCallable
from .handlers import Handler, HandlerCallable
from .middlewares import MiddlewareCallable
from .tdjson import TDJson, TDLibLogVerbosity
from .utils import ainput, PendingRequest, str_to_base64



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject
from ..types import TopChatCategory


class RemoveTopChat(BaseObject):
    """
    Removes a chat from the list of frequently used chats. Supported only if the chat info database is enabled
    
    Params:
        category (:class:`TopChatCategory`)
            Category of frequently used chats
        
        chat_id (:class:`int`)
            Chat identifier
        
    """

    ID: str = Field("removeTopChat", alias="@type")
    category: TopChatCategory
    chat_id: int

    @staticmethod
    def read(q: dict) -> RemoveTopChat:
        return RemoveTopChat.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject
from ..types import ChatAction


class SendChatAction(BaseObject):
    """
    Sends a notification about user activity in a chat
    
    Params:
        chat_id (:class:`int`)
            Chat identifier
        
        message_thread_id (:class:`int`)
            If not 0, a message thread identifier in which the action was performed
        
        action (:class:`ChatAction`)
            The action description
        
    """

    ID: str = Field("sendChatAction", alias="@type")
    chat_id: int
    message_thread_id: int
    action: ChatAction

    @staticmethod
    def read(q: dict) -> SendChatAction:
        return SendChatAction.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

import typing

from pydantic import Field

from .file import File
from .minithumbnail import Minithumbnail
from .thumbnail import Thumbnail
from ..base_object import BaseObject


class Audio(BaseObject):
    """
    Describes an audio file. Audio is usually in MP3 or M4A format
    
    Params:
        duration (:class:`int`)
            Duration of the audio, in seconds; as defined by the sender
        
        title (:class:`str`)
            Title of the audio; as defined by the sender
        
        performer (:class:`str`)
            Performer of the audio; as defined by the sender
        
        file_name (:class:`str`)
            Original name of the file; as defined by the sender
        
        mime_type (:class:`str`)
            The MIME type of the file; as defined by the sender
        
        album_cover_minithumbnail (:class:`Minithumbnail`)
            The minithumbnail of the album cover; may be null
        
        album_cover_thumbnail (:class:`Thumbnail`)
            The thumbnail of the album cover in JPEG format; as defined by the sender. The full size thumbnail should be extracted from the downloaded file; may be null
        
        audio (:class:`File`)
            File containing the audio
        
    """

    ID: str = Field("audio", alias="@type")
    duration: int
    title: str
    performer: str
    file_name: str
    mime_type: str
    album_cover_minithumbnail: typing.Optional[Minithumbnail] = None
    album_cover_thumbnail: typing.Optional[Thumbnail] = None
    audio: File

    @staticmethod
    def read(q: dict) -> Audio:
        return Audio.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class TdlibParameters(BaseObject):
    """
    Contains parameters for TDLib initialization
    
    Params:
        use_test_dc (:class:`bool`)
            If set to true, the Telegram test environment will be used instead of the production environment
        
        database_directory (:class:`str`)
            The path to the directory for the persistent database; if empty, the current working directory will be used
        
        files_directory (:class:`str`)
            The path to the directory for storing files; if empty, database_directory will be used
        
        use_file_database (:class:`bool`)
            If set to true, information about downloaded and uploaded files will be saved between application restarts
        
        use_chat_info_database (:class:`bool`)
            If set to true, the library will maintain a cache of users, basic groups, supergroups, channels and secret chats. Implies use_file_database
        
        use_message_database (:class:`bool`)
            If set to true, the library will maintain a cache of chats and messages. Implies use_chat_info_database
        
        use_secret_chats (:class:`bool`)
            If set to true, support for secret chats will be enabled
        
        api_id (:class:`int`)
            Application identifier for Telegram API access, which can be obtained at https://my.telegram.org
        
        api_hash (:class:`str`)
            Application identifier hash for Telegram API access, which can be obtained at https://my.telegram.org
        
        system_language_code (:class:`str`)
            IETF language tag of the user's operating system language; must be non-empty
        
        device_model (:class:`str`)
            Model of the device the application is being run on; must be non-empty
        
        system_version (:class:`str`)
            Version of the operating system the application is being run on. If empty, the version is automatically detected by TDLib
        
        application_version (:class:`str`)
            Application version; must be non-empty
        
        enable_storage_optimizer (:class:`bool`)
            If set to true, old files will automatically be deleted
        
        ignore_file_names (:class:`bool`)
            If set to true, original file names will be ignored. Otherwise, downloaded files will be saved under names as close as possible to the original name
        
    """

    ID: str = Field("tdlibParameters", alias="@type")
    use_test_dc: bool
    database_directory: str
    files_directory: str
    use_file_database: bool
    use_chat_info_database: bool
    use_message_database: bool
    use_secret_chats: bool
    api_id: int
    api_hash: str
    system_language_code: str
    device_model: str
    system_version: str
    application_version: str
    enable_storage_optimizer: bool
    ignore_file_names: bool

    @staticmethod
    def read(q: dict) -> TdlibParameters:
        return TdlibParameters.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class SupergroupMembersFilter(BaseObject):
    """
    Specifies the kind of chat members to return in getSupergroupMembers
    
    """

    ID: str = Field("supergroupMembersFilter", alias="@type")


class SupergroupMembersFilterAdministrators(SupergroupMembersFilter):
    """
    Returns the owner and administrators
    
    """

    ID: str = Field("supergroupMembersFilterAdministrators", alias="@type")

    @staticmethod
    def read(q: dict) -> SupergroupMembersFilterAdministrators:
        return SupergroupMembersFilterAdministrators.construct(**q)


class SupergroupMembersFilterBanned(SupergroupMembersFilter):
    """
    Returns users banned from the supergroup or channel; can be used only by administrators
    
    Params:
        query (:class:`str`)
            Query to search for
        
    """

    ID: str = Field("supergroupMembersFilterBanned", alias="@type")
    query: str

    @staticmethod
    def read(q: dict) -> SupergroupMembersFilterBanned:
        return SupergroupMembersFilterBanned.construct(**q)


class SupergroupMembersFilterBots(SupergroupMembersFilter):
    """
    Returns bot members of the supergroup or channel
    
    """

    ID: str = Field("supergroupMembersFilterBots", alias="@type")

    @staticmethod
    def read(q: dict) -> SupergroupMembersFilterBots:
        return SupergroupMembersFilterBots.construct(**q)


class SupergroupMembersFilterContacts(SupergroupMembersFilter):
    """
    Returns contacts of the user, which are members of the supergroup or channel
    
    Params:
        query (:class:`str`)
            Query to search for
        
    """

    ID: str = Field("supergroupMembersFilterContacts", alias="@type")
    query: str

    @staticmethod
    def read(q: dict) -> SupergroupMembersFilterContacts:
        return SupergroupMembersFilterContacts.construct(**q)


class SupergroupMembersFilterMention(SupergroupMembersFilter):
    """
    Returns users which can be mentioned in the supergroup
    
    Params:
        query (:class:`str`)
            Query to search for
        
        message_thread_id (:class:`int`)
            If non-zero, the identifier of the current message thread
        
    """

    ID: str = Field("supergroupMembersFilterMention", alias="@type")
    query: str
    message_thread_id: int

    @staticmethod
    def read(q: dict) -> SupergroupMembersFilterMention:
        return SupergroupMembersFilterMention.construct(**q)


class SupergroupMembersFilterRecent(SupergroupMembersFilter):
    """
    Returns recently active users in reverse chronological order
    
    """

    ID: str = Field("supergroupMembersFilterRecent", alias="@type")

    @staticmethod
    def read(q: dict) -> SupergroupMembersFilterRecent:
        return SupergroupMembersFilterRecent.construct(**q)


class SupergroupMembersFilterRestricted(SupergroupMembersFilter):
    """
    Returns restricted supergroup members; can be used only by administrators
    
    Params:
        query (:class:`str`)
            Query to search for
        
    """

    ID: str = Field("supergroupMembersFilterRestricted", alias="@type")
    query: str

    @staticmethod
    def read(q: dict) -> SupergroupMembersFilterRestricted:
        return SupergroupMembersFilterRestricted.construct(**q)


class SupergroupMembersFilterSearch(SupergroupMembersFilter):
    """
    Used to search for supergroup or channel members via a (string) query
    
    Params:
        query (:class:`str`)
            Query to search for
        
    """

    ID: str = Field("supergroupMembersFilterSearch", alias="@type")
    query: str

    @staticmethod
    def read(q: dict) -> SupergroupMembersFilterSearch:
        return SupergroupMembersFilterSearch.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class DeleteAllCallMessages(BaseObject):
    """
    Deletes all call messages
    
    Params:
        revoke (:class:`bool`)
            Pass true to delete the messages for all users
        
    """

    ID: str = Field("deleteAllCallMessages", alias="@type")
    revoke: bool

    @staticmethod
    def read(q: dict) -> DeleteAllCallMessages:
        return DeleteAllCallMessages.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

import typing

from pydantic import Field

from .formatted_text import FormattedText
from ..base_object import BaseObject


class PollType(BaseObject):
    """
    Describes the type of a poll
    
    """

    ID: str = Field("pollType", alias="@type")


class PollTypeQuiz(PollType):
    """
    A poll in quiz mode, which has exactly one correct answer option and can be answered only once
    
    Params:
        correct_option_id (:class:`int`)
            0-based identifier of the correct answer option; -1 for a yet unanswered poll
        
        explanation (:class:`FormattedText`)
            Text that is shown when the user chooses an incorrect answer or taps on the lamp icon; 0-200 characters with at most 2 line feeds; empty for a yet unanswered poll
        
    """

    ID: str = Field("pollTypeQuiz", alias="@type")
    correct_option_id: int
    explanation: typing.Optional[FormattedText] = None

    @staticmethod
    def read(q: dict) -> PollTypeQuiz:
        return PollTypeQuiz.construct(**q)


class PollTypeRegular(PollType):
    """
    A regular poll
    
    Params:
        allow_multiple_answers (:class:`bool`)
            True, if multiple answer options can be chosen simultaneously
        
    """

    ID: str = Field("pollTypeRegular", alias="@type")
    allow_multiple_answers: bool

    @staticmethod
    def read(q: dict) -> PollTypeRegular:
        return PollTypeRegular.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject
from ..types import ChatList


class GetChats(BaseObject):
    """
    Returns an ordered list of chats in a chat list. Chats are sorted by the pair (chat.position.order, chat.id) in descending order. (For example, to get a list of chats from the beginning, the offset_order should be equal to a biggest signed 64-bit number 9223372036854775807 == 2^63 - 1). For optimal performance the number of returned chats is chosen by the library
    
    Params:
        chat_list (:class:`ChatList`)
            The chat list in which to return chats
        
        offset_order (:class:`int`)
            Chat order to return chats from
        
        offset_chat_id (:class:`int`)
            Chat identifier to return chats from
        
        limit (:class:`int`)
            The maximum number of chats to be returned. It is possible that fewer chats than the limit are returned even if the end of the list is not reached
        
    """

    ID: str = Field("getChats", alias="@type")
    chat_list: ChatList
    offset_order: int
    offset_chat_id: int
    limit: int

    @staticmethod
    def read(q: dict) -> GetChats:
        return GetChats.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class GetPassportAuthorizationFormAvailableElements(BaseObject):
    """
    Returns already available Telegram Passport elements suitable for completing a Telegram Passport authorization form. Result can be received only once for each authorization form
    
    Params:
        autorization_form_id (:class:`int`)
            Authorization form identifier
        
        password (:class:`str`)
            Password of the current user
        
    """

    ID: str = Field("getPassportAuthorizationFormAvailableElements", alias="@type")
    autorization_form_id: int
    password: str

    @staticmethod
    def read(q: dict) -> GetPassportAuthorizationFormAvailableElements:
        return GetPassportAuthorizationFormAvailableElements.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class Point(BaseObject):
    """
    A point on a Cartesian plane
    
    Params:
        x (:class:`float`)
            The point's first coordinate
        
        y (:class:`float`)
            The point's second coordinate
        
    """

    ID: str = Field("point", alias="@type")
    x: float
    y: float

    @staticmethod
    def read(q: dict) -> Point:
        return Point.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class GetDeepLinkInfo(BaseObject):
    """
    Returns information about a tg:// deep link. Use "tg://need_update_for_some_feature" or "tg:some_unsupported_feature" for testing. Returns a 404 error for unknown links. Can be called before authorization
    
    Params:
        link (:class:`str`)
            The link
        
    """

    ID: str = Field("getDeepLinkInfo", alias="@type")
    link: str

    @staticmethod
    def read(q: dict) -> GetDeepLinkInfo:
        return GetDeepLinkInfo.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from .chat_administrator import ChatAdministrator
from ..base_object import BaseObject


class ChatAdministrators(BaseObject):
    """
    Represents a list of chat administrators
    
    Params:
        administrators (:obj:`list[ChatAdministrator]`)
            A list of chat administrators
        
    """

    ID: str = Field("chatAdministrators", alias="@type")
    administrators: list[ChatAdministrator]

    @staticmethod
    def read(q: dict) -> ChatAdministrators:
        return ChatAdministrators.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from .input_file import InputFile
from ..base_object import BaseObject


class InputBackground(BaseObject):
    """
    Contains information about background to set
    
    """

    ID: str = Field("inputBackground", alias="@type")


class InputBackgroundLocal(InputBackground):
    """
    A background from a local file
    
    Params:
        background (:class:`InputFile`)
            Background file to use. Only inputFileLocal and inputFileGenerated are supported. The file must be in JPEG format for wallpapers and in PNG format for patterns
        
    """

    ID: str = Field("inputBackgroundLocal", alias="@type")
    background: InputFile

    @staticmethod
    def read(q: dict) -> InputBackgroundLocal:
        return InputBackgroundLocal.construct(**q)


class InputBackgroundRemote(InputBackground):
    """
    A background from the server
    
    Params:
        background_id (:class:`int`)
            The background identifier
        
    """

    ID: str = Field("inputBackgroundRemote", alias="@type")
    background_id: int

    @staticmethod
    def read(q: dict) -> InputBackgroundRemote:
        return InputBackgroundRemote.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class GetBlockedMessageSenders(BaseObject):
    """
    Returns users and chats that were blocked by the current user
    
    Params:
        offset (:class:`int`)
            Number of users and chats to skip in the result; must be non-negative
        
        limit (:class:`int`)
            The maximum number of users and chats to return; up to 100
        
    """

    ID: str = Field("getBlockedMessageSenders", alias="@type")
    offset: int
    limit: int

    @staticmethod
    def read(q: dict) -> GetBlockedMessageSenders:
        return GetBlockedMessageSenders.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class GetChatStatisticsUrl(BaseObject):
    """
    Returns an HTTP URL with the chat statistics. Currently this method of getting the statistics are disabled and can be deleted in the future
    
    Params:
        chat_id (:class:`int`)
            Chat identifier
        
        parameters (:class:`str`)
            Parameters from "tg://statsrefresh?params=******" link
        
        is_dark (:class:`bool`)
            Pass true if a URL with the dark theme must be returned
        
    """

    ID: str = Field("getChatStatisticsUrl", alias="@type")
    chat_id: int
    parameters: str
    is_dark: bool

    @staticmethod
    def read(q: dict) -> GetChatStatisticsUrl:
        return GetChatStatisticsUrl.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class GetPaymentForm(BaseObject):
    """
    Returns an invoice payment form. This method should be called when the user presses inlineKeyboardButtonBuy
    
    Params:
        chat_id (:class:`int`)
            Chat identifier of the Invoice message
        
        message_id (:class:`int`)
            Message identifier
        
    """

    ID: str = Field("getPaymentForm", alias="@type")
    chat_id: int
    message_id: int

    @staticmethod
    def read(q: dict) -> GetPaymentForm:
        return GetPaymentForm.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from .language_pack_string import LanguagePackString
from ..base_object import BaseObject


class LanguagePackStrings(BaseObject):
    """
    Contains a list of language pack strings
    
    Params:
        strings (:obj:`list[LanguagePackString]`)
            A list of language pack strings
        
    """

    ID: str = Field("languagePackStrings", alias="@type")
    strings: list[LanguagePackString]

    @staticmethod
    def read(q: dict) -> LanguagePackStrings:
        return LanguagePackStrings.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class CleanFileName(BaseObject):
    """
    Removes potentially dangerous characters from the name of a file. The encoding of the file name is supposed to be UTF-8. Returns an empty string on failure. Can be called synchronously
    
    Params:
        file_name (:class:`str`)
            File name or path to the file
        
    """

    ID: str = Field("cleanFileName", alias="@type")
    file_name: str

    @staticmethod
    def read(q: dict) -> CleanFileName:
        return CleanFileName.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class InputPassportElementErrorSource(BaseObject):
    """
    Contains the description of an error in a Telegram Passport element; for bots only
    
    """

    ID: str = Field("inputPassportElementErrorSource", alias="@type")


class InputPassportElementErrorSourceDataField(InputPassportElementErrorSource):
    """
    A data field contains an error. The error is considered resolved when the field's value changes
    
    Params:
        field_name (:class:`str`)
            Field name
        
        data_hash (:class:`str`)
            Current data hash
        
    """

    ID: str = Field("inputPassportElementErrorSourceDataField", alias="@type")
    field_name: str
    data_hash: str

    @staticmethod
    def read(q: dict) -> InputPassportElementErrorSourceDataField:
        return InputPassportElementErrorSourceDataField.construct(**q)


class InputPassportElementErrorSourceFile(InputPassportElementErrorSource):
    """
    The file contains an error. The error is considered resolved when the file changes
    
    Params:
        file_hash (:class:`str`)
            Current hash of the file which has the error
        
    """

    ID: str = Field("inputPassportElementErrorSourceFile", alias="@type")
    file_hash: str

    @staticmethod
    def read(q: dict) -> InputPassportElementErrorSourceFile:
        return InputPassportElementErrorSourceFile.construct(**q)


class InputPassportElementErrorSourceFiles(InputPassportElementErrorSource):
    """
    The list of attached files contains an error. The error is considered resolved when the file list changes
    
    Params:
        file_hashes (:obj:`list[str]`)
            Current hashes of all attached files
        
    """

    ID: str = Field("inputPassportElementErrorSourceFiles", alias="@type")
    file_hashes: list[str]

    @staticmethod
    def read(q: dict) -> InputPassportElementErrorSourceFiles:
        return InputPassportElementErrorSourceFiles.construct(**q)


class InputPassportElementErrorSourceFrontSide(InputPassportElementErrorSource):
    """
    The front side of the document contains an error. The error is considered resolved when the file with the front side of the document changes
    
    Params:
        file_hash (:class:`str`)
            Current hash of the file containing the front side
        
    """

    ID: str = Field("inputPassportElementErrorSourceFrontSide", alias="@type")
    file_hash: str

    @staticmethod
    def read(q: dict) -> InputPassportElementErrorSourceFrontSide:
        return InputPassportElementErrorSourceFrontSide.construct(**q)


class InputPassportElementErrorSourceReverseSide(InputPassportElementErrorSource):
    """
    The reverse side of the document contains an error. The error is considered resolved when the file with the reverse side of the document changes
    
    Params:
        file_hash (:class:`str`)
            Current hash of the file containing the reverse side
        
    """

    ID: str = Field("inputPassportElementErrorSourceReverseSide", alias="@type")
    file_hash: str

    @staticmethod
    def read(q: dict) -> InputPassportElementErrorSourceReverseSide:
        return InputPassportElementErrorSourceReverseSide.construct(**q)


class InputPassportElementErrorSourceSelfie(InputPassportElementErrorSource):
    """
    The selfie contains an error. The error is considered resolved when the file with the selfie changes
    
    Params:
        file_hash (:class:`str`)
            Current hash of the file containing the selfie
        
    """

    ID: str = Field("inputPassportElementErrorSourceSelfie", alias="@type")
    file_hash: str

    @staticmethod
    def read(q: dict) -> InputPassportElementErrorSourceSelfie:
        return InputPassportElementErrorSourceSelfie.construct(**q)


class InputPassportElementErrorSourceTranslationFile(InputPassportElementErrorSource):
    """
    One of the files containing the translation of the document contains an error. The error is considered resolved when the file with the translation changes
    
    Params:
        file_hash (:class:`str`)
            Current hash of the file containing the translation
        
    """

    ID: str = Field("inputPassportElementErrorSourceTranslationFile", alias="@type")
    file_hash: str

    @staticmethod
    def read(q: dict) -> InputPassportElementErrorSourceTranslationFile:
        return InputPassportElementErrorSourceTranslationFile.construct(**q)


class InputPassportElementErrorSourceTranslationFiles(InputPassportElementErrorSource):
    """
    The translation of the document contains an error. The error is considered resolved when the list of files changes
    
    Params:
        file_hashes (:obj:`list[str]`)
            Current hashes of all files with the translation
        
    """

    ID: str = Field("inputPassportElementErrorSourceTranslationFiles", alias="@type")
    file_hashes: list[str]

    @staticmethod
    def read(q: dict) -> InputPassportElementErrorSourceTranslationFiles:
        return InputPassportElementErrorSourceTranslationFiles.construct(**q)


class InputPassportElementErrorSourceUnspecified(InputPassportElementErrorSource):
    """
    The element contains an error in an unspecified place. The error will be considered resolved when new data is added
    
    Params:
        element_hash (:class:`str`)
            Current hash of the entire element
        
    """

    ID: str = Field("inputPassportElementErrorSourceUnspecified", alias="@type")
    element_hash: str

    @staticmethod
    def read(q: dict) -> InputPassportElementErrorSourceUnspecified:
        return InputPassportElementErrorSourceUnspecified.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class DateRange(BaseObject):
    """
    Represents a date range
    
    Params:
        start_date (:class:`int`)
            Point in time (Unix timestamp) at which the date range begins
        
        end_date (:class:`int`)
            Point in time (Unix timestamp) at which the date range ends
        
    """

    ID: str = Field("dateRange", alias="@type")
    start_date: int
    end_date: int

    @staticmethod
    def read(q: dict) -> DateRange:
        return DateRange.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class ChatList(BaseObject):
    """
    Describes a list of chats
    
    """

    ID: str = Field("chatList", alias="@type")


class ChatListArchive(ChatList):
    """
    A list of chats usually located at the top of the main chat list. Unmuted chats are automatically moved from the Archive to the Main chat list when a new message arrives
    
    """

    ID: str = Field("chatListArchive", alias="@type")

    @staticmethod
    def read(q: dict) -> ChatListArchive:
        return ChatListArchive.construct(**q)


class ChatListFilter(ChatList):
    """
    A list of chats belonging to a chat filter
    
    Params:
        chat_filter_id (:class:`int`)
            Chat filter identifier
        
    """

    ID: str = Field("chatListFilter", alias="@type")
    chat_filter_id: int

    @staticmethod
    def read(q: dict) -> ChatListFilter:
        return ChatListFilter.construct(**q)


class ChatListMain(ChatList):
    """
    A main list of chats
    
    """

    ID: str = Field("chatListMain", alias="@type")

    @staticmethod
    def read(q: dict) -> ChatListMain:
        return ChatListMain.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject
from ..types import InputFile


class SetStickerPositionInSet(BaseObject):
    """
    Changes the position of a sticker in the set to which it belongs; for bots only. The sticker set must have been created by the bot
    
    Params:
        sticker (:class:`InputFile`)
            Sticker
        
        position (:class:`int`)
            New position of the sticker in the set, zero-based
        
    """

    ID: str = Field("setStickerPositionInSet", alias="@type")
    sticker: InputFile
    position: int

    @staticmethod
    def read(q: dict) -> SetStickerPositionInSet:
        return SetStickerPositionInSet.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class AddChatMember(BaseObject):
    """
    Adds a new member to a chat. Members can't be added to private or secret chats
    
    Params:
        chat_id (:class:`int`)
            Chat identifier
        
        user_id (:class:`int`)
            Identifier of the user
        
        forward_limit (:class:`int`)
            The number of earlier messages from the chat to be forwarded to the new member; up to 100. Ignored for supergroups and channels
        
    """

    ID: str = Field("addChatMember", alias="@type")
    chat_id: int
    user_id: int
    forward_limit: int

    @staticmethod
    def read(q: dict) -> AddChatMember:
        return AddChatMember.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

import typing

from pydantic import Field

from .bot_info import BotInfo
from .chat_member_status import ChatMemberStatus
from ..base_object import BaseObject


class ChatMember(BaseObject):
    """
    A user with information about joining/leaving a chat
    
    Params:
        user_id (:class:`int`)
            User identifier of the chat member
        
        inviter_user_id (:class:`int`)
            Identifier of a user that invited/promoted/banned this member in the chat; 0 if unknown
        
        joined_chat_date (:class:`int`)
            Point in time (Unix timestamp) when the user joined the chat
        
        status (:class:`ChatMemberStatus`)
            Status of the member in the chat
        
        bot_info (:class:`BotInfo`)
            If the user is a bot, information about the bot; may be null. Can be null even for a bot if the bot is not the chat member
        
    """

    ID: str = Field("chatMember", alias="@type")
    user_id: int
    inviter_user_id: int
    joined_chat_date: int
    status: ChatMemberStatus
    bot_info: typing.Optional[BotInfo] = None

    @staticmethod
    def read(q: dict) -> ChatMember:
        return ChatMember.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class NetworkType(BaseObject):
    """
    Represents the type of a network
    
    """

    ID: str = Field("networkType", alias="@type")


class NetworkTypeMobile(NetworkType):
    """
    A mobile network
    
    """

    ID: str = Field("networkTypeMobile", alias="@type")

    @staticmethod
    def read(q: dict) -> NetworkTypeMobile:
        return NetworkTypeMobile.construct(**q)


class NetworkTypeMobileRoaming(NetworkType):
    """
    A mobile roaming network
    
    """

    ID: str = Field("networkTypeMobileRoaming", alias="@type")

    @staticmethod
    def read(q: dict) -> NetworkTypeMobileRoaming:
        return NetworkTypeMobileRoaming.construct(**q)


class NetworkTypeNone(NetworkType):
    """
    The network is not available
    
    """

    ID: str = Field("networkTypeNone", alias="@type")

    @staticmethod
    def read(q: dict) -> NetworkTypeNone:
        return NetworkTypeNone.construct(**q)


class NetworkTypeOther(NetworkType):
    """
    A different network type (e.g., Ethernet network)
    
    """

    ID: str = Field("networkTypeOther", alias="@type")

    @staticmethod
    def read(q: dict) -> NetworkTypeOther:
        return NetworkTypeOther.construct(**q)


class NetworkTypeWiFi(NetworkType):
    """
    A Wi-Fi network
    
    """

    ID: str = Field("networkTypeWiFi", alias="@type")

    @staticmethod
    def read(q: dict) -> NetworkTypeWiFi:
        return NetworkTypeWiFi.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

import typing

from pydantic import Field

from .animation import Animation
from .audio import Audio
from .document import Document
from .formatted_text import FormattedText
from .photo import Photo
from .sticker import Sticker
from .video import Video
from .video_note import VideoNote
from .voice_note import VoiceNote
from ..base_object import BaseObject


class WebPage(BaseObject):
    """
    Describes a web page preview
    
    Params:
        url (:class:`str`)
            Original URL of the link
        
        display_url (:class:`str`)
            URL to display
        
        type_ (:class:`str`)
            Type of the web page. Can be: article, photo, audio, video, document, profile, app, or something else
        
        site_name (:class:`str`)
            Short name of the site (e.g., Google Docs, App Store)
        
        title (:class:`str`)
            Title of the content
        
        param_description (:class:`FormattedText`)
            Description of the content
        
        photo (:class:`Photo`)
            Image representing the content; may be null
        
        embed_url (:class:`str`)
            URL to show in the embedded preview
        
        embed_type (:class:`str`)
            MIME type of the embedded preview, (e.g., text/html or video/mp4)
        
        embed_width (:class:`int`)
            Width of the embedded preview
        
        embed_height (:class:`int`)
            Height of the embedded preview
        
        duration (:class:`int`)
            Duration of the content, in seconds
        
        author (:class:`str`)
            Author of the content
        
        animation (:class:`Animation`)
            Preview of the content as an animation, if available; may be null
        
        audio (:class:`Audio`)
            Preview of the content as an audio file, if available; may be null
        
        document (:class:`Document`)
            Preview of the content as a document, if available (currently only available for small PDF files and ZIP archives); may be null
        
        sticker (:class:`Sticker`)
            Preview of the content as a sticker for small WEBP files, if available; may be null
        
        video (:class:`Video`)
            Preview of the content as a video, if available; may be null
        
        video_note (:class:`VideoNote`)
            Preview of the content as a video note, if available; may be null
        
        voice_note (:class:`VoiceNote`)
            Preview of the content as a voice note, if available; may be null
        
        instant_view_version (:class:`int`)
            Version of instant view, available for the web page (currently can be 1 or 2), 0 if none
        
    """

    ID: str = Field("webPage", alias="@type")
    url: str
    display_url: str
    type_: str = Field(..., alias='type')
    site_name: str
    title: str
    param_description: FormattedText
    photo: typing.Optional[Photo] = None
    embed_url: str
    embed_type: str
    embed_width: int
    embed_height: int
    duration: int
    author: str
    animation: typing.Optional[Animation] = None
    audio: typing.Optional[Audio] = None
    document: typing.Optional[Document] = None
    sticker: typing.Optional[Sticker] = None
    video: typing.Optional[Video] = None
    video_note: typing.Optional[VideoNote] = None
    voice_note: typing.Optional[VoiceNote] = None
    instant_view_version: int

    @staticmethod
    def read(q: dict) -> WebPage:
        return WebPage.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from .group_call_payload_fingerprint import GroupCallPayloadFingerprint
from ..base_object import BaseObject


class GroupCallPayload(BaseObject):
    """
    Describes a payload for interaction with tgcalls
    
    Params:
        ufrag (:class:`str`)
            Value of the field ufrag
        
        pwd (:class:`str`)
            Value of the field pwd
        
        fingerprints (:obj:`list[GroupCallPayloadFingerprint]`)
            The list of fingerprints
        
    """

    ID: str = Field("groupCallPayload", alias="@type")
    ufrag: str
    pwd: str
    fingerprints: list[GroupCallPayloadFingerprint]

    @staticmethod
    def read(q: dict) -> GroupCallPayload:
        return GroupCallPayload.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class ChatInviteLinkMember(BaseObject):
    """
    Describes a chat member joined a chat by an invite link
    
    Params:
        user_id (:class:`int`)
            User identifier
        
        joined_chat_date (:class:`int`)
            Point in time (Unix timestamp) when the user joined the chat
        
    """

    ID: str = Field("chatInviteLinkMember", alias="@type")
    user_id: int
    joined_chat_date: int

    @staticmethod
    def read(q: dict) -> ChatInviteLinkMember:
        return ChatInviteLinkMember.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class ChatFilterInfo(BaseObject):
    """
    Contains basic information about a chat filter
    
    Params:
        id (:class:`int`)
            Unique chat filter identifier
        
        title (:class:`str`)
            The title of the filter; 1-12 characters without line feeds
        
        icon_name (:class:`str`)
            The icon name for short filter representation. One of "All", "Unread", "Unmuted", "Bots", "Channels", "Groups", "Private", "Custom", "Setup", "Cat", "Crown", "Favorite", "Flower", "Game", "Home", "Love", "Mask", "Party", "Sport", "Study", "Trade", "Travel", "Work"
        
    """

    ID: str = Field("chatFilterInfo", alias="@type")
    id: int
    title: str = Field(..., min_length=1, max_length=12)
    icon_name: str

    @staticmethod
    def read(q: dict) -> ChatFilterInfo:
        return ChatFilterInfo.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from .chat_nearby import ChatNearby
from ..base_object import BaseObject


class ChatsNearby(BaseObject):
    """
    Represents a list of chats located nearby
    
    Params:
        users_nearby (:obj:`list[ChatNearby]`)
            List of users nearby
        
        supergroups_nearby (:obj:`list[ChatNearby]`)
            List of location-based supergroups nearby
        
    """

    ID: str = Field("chatsNearby", alias="@type")
    users_nearby: list[ChatNearby]
    supergroups_nearby: list[ChatNearby]

    @staticmethod
    def read(q: dict) -> ChatsNearby:
        return ChatsNearby.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

import typing

from pydantic import Field

from .file import File
from .minithumbnail import Minithumbnail
from .thumbnail import Thumbnail
from ..base_object import BaseObject


class Document(BaseObject):
    """
    Describes a document of any type
    
    Params:
        file_name (:class:`str`)
            Original name of the file; as defined by the sender
        
        mime_type (:class:`str`)
            MIME type of the file; as defined by the sender
        
        minithumbnail (:class:`Minithumbnail`)
            Document minithumbnail; may be null
        
        thumbnail (:class:`Thumbnail`)
            Document thumbnail in JPEG or PNG format (PNG will be used only for background patterns); as defined by the sender; may be null
        
        document (:class:`File`)
            File containing the document
        
    """

    ID: str = Field("document", alias="@type")
    file_name: str
    mime_type: str
    minithumbnail: typing.Optional[Minithumbnail] = None
    thumbnail: typing.Optional[Thumbnail] = None
    document: File

    @staticmethod
    def read(q: dict) -> Document:
        return Document.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from .input_message_content import InputMessageContent
from ..base_object import BaseObject


class DraftMessage(BaseObject):
    """
    Contains information about a message draft
    
    Params:
        reply_to_message_id (:class:`int`)
            Identifier of the message to reply to; 0 if none
        
        date (:class:`int`)
            Point in time (Unix timestamp) when the draft was created
        
        input_message_text (:class:`InputMessageContent`)
            Content of the message draft; this should always be of type inputMessageText
        
    """

    ID: str = Field("draftMessage", alias="@type")
    reply_to_message_id: int
    date: int
    input_message_text: InputMessageContent

    @staticmethod
    def read(q: dict) -> DraftMessage:
        return DraftMessage.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class LeaveGroupCall(BaseObject):
    """
    Leaves a group call
    
    Params:
        group_call_id (:class:`int`)
            Group call identifier
        
    """

    ID: str = Field("leaveGroupCall", alias="@type")
    group_call_id: int

    @staticmethod
    def read(q: dict) -> LeaveGroupCall:
        return LeaveGroupCall.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from .notification_type import NotificationType
from ..base_object import BaseObject


class Notification(BaseObject):
    """
    Contains information about a notification
    
    Params:
        id (:class:`int`)
            Unique persistent identifier of this notification
        
        date (:class:`int`)
            Notification date
        
        is_silent (:class:`bool`)
            True, if the notification was initially silent
        
        type_ (:class:`NotificationType`)
            Notification type
        
    """

    ID: str = Field("notification", alias="@type")
    id: int
    date: int
    is_silent: bool
    type_: NotificationType = Field(..., alias='type')

    @staticmethod
    def read(q: dict) -> Notification:
        return Notification.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from .t_me_url import TMeUrl
from ..base_object import BaseObject


class TMeUrls(BaseObject):
    """
    Contains a list of t.me URLs
    
    Params:
        urls (:obj:`list[TMeUrl]`)
            List of URLs
        
    """

    ID: str = Field("tMeUrls", alias="@type")
    urls: list[TMeUrl]

    @staticmethod
    def read(q: dict) -> TMeUrls:
        return TMeUrls.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class CallDiscardReason(BaseObject):
    """
    Describes the reason why a call was discarded
    
    """

    ID: str = Field("callDiscardReason", alias="@type")


class CallDiscardReasonDeclined(CallDiscardReason):
    """
    The call was ended before the conversation started. It was declined by the other party
    
    """

    ID: str = Field("callDiscardReasonDeclined", alias="@type")

    @staticmethod
    def read(q: dict) -> CallDiscardReasonDeclined:
        return CallDiscardReasonDeclined.construct(**q)


class CallDiscardReasonDisconnected(CallDiscardReason):
    """
    The call was ended during the conversation because the users were disconnected
    
    """

    ID: str = Field("callDiscardReasonDisconnected", alias="@type")

    @staticmethod
    def read(q: dict) -> CallDiscardReasonDisconnected:
        return CallDiscardReasonDisconnected.construct(**q)


class CallDiscardReasonEmpty(CallDiscardReason):
    """
    The call wasn't discarded, or the reason is unknown
    
    """

    ID: str = Field("callDiscardReasonEmpty", alias="@type")

    @staticmethod
    def read(q: dict) -> CallDiscardReasonEmpty:
        return CallDiscardReasonEmpty.construct(**q)


class CallDiscardReasonHungUp(CallDiscardReason):
    """
    The call was ended because one of the parties hung up
    
    """

    ID: str = Field("callDiscardReasonHungUp", alias="@type")

    @staticmethod
    def read(q: dict) -> CallDiscardReasonHungUp:
        return CallDiscardReasonHungUp.construct(**q)


class CallDiscardReasonMissed(CallDiscardReason):
    """
    The call was ended before the conversation started. It was cancelled by the caller or missed by the other party
    
    """

    ID: str = Field("callDiscardReasonMissed", alias="@type")

    @staticmethod
    def read(q: dict) -> CallDiscardReasonMissed:
        return CallDiscardReasonMissed.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from .language_pack_string_value import LanguagePackStringValue
from ..base_object import BaseObject


class LanguagePackString(BaseObject):
    """
    Represents one language pack string
    
    Params:
        key (:class:`str`)
            String key
        
        value (:class:`LanguagePackStringValue`)
            String value
        
    """

    ID: str = Field("languagePackString", alias="@type")
    key: str
    value: LanguagePackStringValue

    @staticmethod
    def read(q: dict) -> LanguagePackString:
        return LanguagePackString.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class SendCustomRequest(BaseObject):
    """
    Sends a custom request; for bots only
    
    Params:
        method (:class:`str`)
            The method name
        
        parameters (:class:`str`)
            JSON-serialized method parameters
        
    """

    ID: str = Field("sendCustomRequest", alias="@type")
    method: str
    parameters: str

    @staticmethod
    def read(q: dict) -> SendCustomRequest:
        return SendCustomRequest.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class SearchChatsOnServer(BaseObject):
    """
    Searches for the specified query in the title and username of already known chats via request to the server. Returns chats in the order seen in the main chat list
    
    Params:
        query (:class:`str`)
            Query to search for
        
        limit (:class:`int`)
            The maximum number of chats to be returned
        
    """

    ID: str = Field("searchChatsOnServer", alias="@type")
    query: str
    limit: int

    @staticmethod
    def read(q: dict) -> SearchChatsOnServer:
        return SearchChatsOnServer.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class SearchInstalledStickerSets(BaseObject):
    """
    Searches for installed sticker sets by looking for specified query in their title and name
    
    Params:
        is_masks (:class:`bool`)
            Pass true to return mask sticker sets; pass false to return ordinary sticker sets
        
        query (:class:`str`)
            Query to search for
        
        limit (:class:`int`)
            The maximum number of sticker sets to return
        
    """

    ID: str = Field("searchInstalledStickerSets", alias="@type")
    is_masks: bool
    query: str
    limit: int

    @staticmethod
    def read(q: dict) -> SearchInstalledStickerSets:
        return SearchInstalledStickerSets.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class PinChatMessage(BaseObject):
    """
    Pins a message in a chat; requires can_pin_messages rights or can_edit_messages rights in the channel
    
    Params:
        chat_id (:class:`int`)
            Identifier of the chat
        
        message_id (:class:`int`)
            Identifier of the new pinned message
        
        disable_notification (:class:`bool`)
            True, if there should be no notification about the pinned message. Notifications are always disabled in channels and private chats
        
        only_for_self (:class:`bool`)
            True, if the message needs to be pinned for one side only; private chats only
        
    """

    ID: str = Field("pinChatMessage", alias="@type")
    chat_id: int
    message_id: int
    disable_notification: bool
    only_for_self: bool

    @staticmethod
    def read(q: dict) -> PinChatMessage:
        return PinChatMessage.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class GetInviteText(BaseObject):
    """
    Returns the default text for invitation messages to be used as a placeholder when the current user invites friends to Telegram
    
    """

    ID: str = Field("getInviteText", alias="@type")

    @staticmethod
    def read(q: dict) -> GetInviteText:
        return GetInviteText.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from .input_passport_element_error_source import InputPassportElementErrorSource
from .passport_element_type import PassportElementType
from ..base_object import BaseObject


class InputPassportElementError(BaseObject):
    """
    Contains the description of an error in a Telegram Passport element; for bots only
    
    Params:
        type_ (:class:`PassportElementType`)
            Type of Telegram Passport element that has the error
        
        message (:class:`str`)
            Error message
        
        source (:class:`InputPassportElementErrorSource`)
            Error source
        
    """

    ID: str = Field("inputPassportElementError", alias="@type")
    type_: PassportElementType = Field(..., alias='type')
    message: str
    source: InputPassportElementErrorSource

    @staticmethod
    def read(q: dict) -> InputPassportElementError:
        return InputPassportElementError.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

import typing

from pydantic import Field

from .message_content import MessageContent
from .message_forward_info import MessageForwardInfo
from .message_interaction_info import MessageInteractionInfo
from .message_scheduling_state import MessageSchedulingState
from .message_sender import MessageSender
from .message_sending_state import MessageSendingState
from .reply_markup import ReplyMarkup
from ..base_object import BaseObject


class Message(BaseObject):
    """
    Describes a message
    
    Params:
        id (:class:`int`)
            Message identifier; unique for the chat to which the message belongs
        
        sender (:class:`MessageSender`)
            The sender of the message
        
        chat_id (:class:`int`)
            Chat identifier
        
        sending_state (:class:`MessageSendingState`)
            Information about the sending state of the message; may be null
        
        scheduling_state (:class:`MessageSchedulingState`)
            Information about the scheduling state of the message; may be null
        
        is_outgoing (:class:`bool`)
            True, if the message is outgoing
        
        is_pinned (:class:`bool`)
            True, if the message is pinned
        
        can_be_edited (:class:`bool`)
            True, if the message can be edited. For live location and poll messages this fields shows whether editMessageLiveLocation or stopPoll can be used with this message by the application
        
        can_be_forwarded (:class:`bool`)
            True, if the message can be forwarded
        
        can_be_deleted_only_for_self (:class:`bool`)
            True, if the message can be deleted only for the current user while other users will continue to see it
        
        can_be_deleted_for_all_users (:class:`bool`)
            True, if the message can be deleted for all users
        
        can_get_statistics (:class:`bool`)
            True, if the message statistics are available
        
        can_get_message_thread (:class:`bool`)
            True, if the message thread info is available
        
        is_channel_post (:class:`bool`)
            True, if the message is a channel post. All messages to channels are channel posts, all other messages are not channel posts
        
        contains_unread_mention (:class:`bool`)
            True, if the message contains an unread mention for the current user
        
        date (:class:`int`)
            Point in time (Unix timestamp) when the message was sent
        
        edit_date (:class:`int`)
            Point in time (Unix timestamp) when the message was last edited
        
        forward_info (:class:`MessageForwardInfo`)
            Information about the initial message sender; may be null
        
        interaction_info (:class:`MessageInteractionInfo`)
            Information about interactions with the message; may be null
        
        reply_in_chat_id (:class:`int`)
            If non-zero, the identifier of the chat to which the replied message belongs; Currently, only messages in the Replies chat can have different reply_in_chat_id and chat_id
        
        reply_to_message_id (:class:`int`)
            If non-zero, the identifier of the message this message is replying to; can be the identifier of a deleted message
        
        message_thread_id (:class:`int`)
            If non-zero, the identifier of the message thread the message belongs to; unique within the chat to which the message belongs
        
        ttl (:class:`int`)
            For self-destructing messages, the message's TTL (Time To Live), in seconds; 0 if none. TDLib will send updateDeleteMessages or updateMessageContent once the TTL expires
        
        ttl_expires_in (:class:`float`)
            Time left before the message expires, in seconds
        
        via_bot_user_id (:class:`int`)
            If non-zero, the user identifier of the bot through which this message was sent
        
        author_signature (:class:`str`)
            For channel posts and anonymous group messages, optional author signature
        
        media_album_id (:class:`int`)
            Unique identifier of an album this message belongs to. Only audios, documents, photos and videos can be grouped together in albums
        
        restriction_reason (:class:`str`)
            If non-empty, contains a human-readable description of the reason why access to this message must be restricted
        
        content (:class:`MessageContent`)
            Content of the message
        
        reply_markup (:class:`ReplyMarkup`)
            Reply markup for the message; may be null
        
    """

    ID: str = Field("message", alias="@type")
    id: int
    sender: MessageSender
    chat_id: int
    sending_state: typing.Optional[MessageSendingState] = None
    scheduling_state: typing.Optional[MessageSchedulingState] = None
    is_outgoing: bool
    is_pinned: bool
    can_be_edited: bool
    can_be_forwarded: bool
    can_be_deleted_only_for_self: bool
    can_be_deleted_for_all_users: bool
    can_get_statistics: bool
    can_get_message_thread: bool
    is_channel_post: bool
    contains_unread_mention: bool
    date: int
    edit_date: int
    forward_info: typing.Optional[MessageForwardInfo] = None
    interaction_info: typing.Optional[MessageInteractionInfo] = None
    reply_in_chat_id: int
    reply_to_message_id: int
    message_thread_id: int
    ttl: int
    ttl_expires_in: float
    via_bot_user_id: int
    author_signature: str
    media_album_id: int
    restriction_reason: str
    content: MessageContent
    reply_markup: typing.Optional[ReplyMarkup] = None

    @staticmethod
    def read(q: dict) -> Message:
        return Message.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject
from ..types import DeviceToken


class RegisterDevice(BaseObject):
    """
    Registers the currently used device for receiving push notifications. Returns a globally unique identifier of the push notification subscription
    
    Params:
        device_token (:class:`DeviceToken`)
            Device token
        
        other_user_ids (:obj:`list[int]`)
            List of user identifiers of other users currently using the application
        
    """

    ID: str = Field("registerDevice", alias="@type")
    device_token: DeviceToken
    other_user_ids: list[int]

    @staticmethod
    def read(q: dict) -> RegisterDevice:
        return RegisterDevice.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject
from ..types import NotificationSettingsScope, ScopeNotificationSettings


class SetScopeNotificationSettings(BaseObject):
    """
    Changes notification settings for chats of a given type
    
    Params:
        scope (:class:`NotificationSettingsScope`)
            Types of chats for which to change the notification settings
        
        notification_settings (:class:`ScopeNotificationSettings`)
            The new notification settings for the given scope
        
    """

    ID: str = Field("setScopeNotificationSettings", alias="@type")
    scope: NotificationSettingsScope
    notification_settings: ScopeNotificationSettings

    @staticmethod
    def read(q: dict) -> SetScopeNotificationSettings:
        return SetScopeNotificationSettings.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class PollOption(BaseObject):
    """
    Describes one answer option of a poll
    
    Params:
        text (:class:`str`)
            Option text; 1-100 characters
        
        voter_count (:class:`int`)
            Number of voters for this option, available only for closed or voted polls
        
        vote_percentage (:class:`int`)
            The percentage of votes for this option; 0-100
        
        is_chosen (:class:`bool`)
            True, if the option was chosen by the user
        
        is_being_chosen (:class:`bool`)
            True, if the option is being chosen by a pending setPollAnswer request
        
    """

    ID: str = Field("pollOption", alias="@type")
    text: str = Field(..., min_length=1, max_length=100)
    voter_count: int
    vote_percentage: int
    is_chosen: bool
    is_being_chosen: bool

    @staticmethod
    def read(q: dict) -> PollOption:
        return PollOption.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject
from ..types import ChatFilter


class EditChatFilter(BaseObject):
    """
    Edits existing chat filter. Returns information about the edited chat filter
    
    Params:
        chat_filter_id (:class:`int`)
            Chat filter identifier
        
        filter_ (:class:`ChatFilter`)
            The edited chat filter
        
    """

    ID: str = Field("editChatFilter", alias="@type")
    chat_filter_id: int
    filter_: ChatFilter = Field(..., alias='filter')

    @staticmethod
    def read(q: dict) -> EditChatFilter:
        return EditChatFilter.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class CheckChangePhoneNumberCode(BaseObject):
    """
    Checks the authentication code sent to confirm a new phone number of the user
    
    Params:
        code (:class:`str`)
            Verification code received by SMS, phone call or flash call
        
    """

    ID: str = Field("checkChangePhoneNumberCode", alias="@type")
    code: str

    @staticmethod
    def read(q: dict) -> CheckChangePhoneNumberCode:
        return CheckChangePhoneNumberCode.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from .chat_photo import ChatPhoto
from ..base_object import BaseObject


class ChatPhotos(BaseObject):
    """
    Contains a list of chat or user profile photos
    
    Params:
        total_count (:class:`int`)
            Total number of photos
        
        photos (:obj:`list[ChatPhoto]`)
            List of photos
        
    """

    ID: str = Field("chatPhotos", alias="@type")
    total_count: int
    photos: list[ChatPhoto]

    @staticmethod
    def read(q: dict) -> ChatPhotos:
        return ChatPhotos.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class ChatActionBar(BaseObject):
    """
    Describes actions which should be possible to do through a chat action bar
    
    """

    ID: str = Field("chatActionBar", alias="@type")


class ChatActionBarAddContact(ChatActionBar):
    """
    The chat is a private or secret chat and the other user can be added to the contact list using the method addContact
    
    """

    ID: str = Field("chatActionBarAddContact", alias="@type")

    @staticmethod
    def read(q: dict) -> ChatActionBarAddContact:
        return ChatActionBarAddContact.construct(**q)


class ChatActionBarInviteMembers(ChatActionBar):
    """
    The chat is a recently created group chat, to which new members can be invited
    
    """

    ID: str = Field("chatActionBarInviteMembers", alias="@type")

    @staticmethod
    def read(q: dict) -> ChatActionBarInviteMembers:
        return ChatActionBarInviteMembers.construct(**q)


class ChatActionBarReportAddBlock(ChatActionBar):
    """
    The chat is a private or secret chat, which can be reported using the method reportChat, or the other user can be blocked using the method blockUser, or the other user can be added to the contact list using the method addContact
    
    Params:
        can_unarchive (:class:`bool`)
            If true, the chat was automatically archived and can be moved back to the main chat list using addChatToList simultaneously with setting chat notification settings to default using setChatNotificationSettings
        
        distance (:class:`int`)
            If non-negative, the current user was found by the peer through searchChatsNearby and this is the distance between the users
        
    """

    ID: str = Field("chatActionBarReportAddBlock", alias="@type")
    can_unarchive: bool
    distance: int

    @staticmethod
    def read(q: dict) -> ChatActionBarReportAddBlock:
        return ChatActionBarReportAddBlock.construct(**q)


class ChatActionBarReportSpam(ChatActionBar):
    """
    The chat can be reported as spam using the method reportChat with the reason chatReportReasonSpam
    
    Params:
        can_unarchive (:class:`bool`)
            If true, the chat was automatically archived and can be moved back to the main chat list using addChatToList simultaneously with setting chat notification settings to default using setChatNotificationSettings
        
    """

    ID: str = Field("chatActionBarReportSpam", alias="@type")
    can_unarchive: bool

    @staticmethod
    def read(q: dict) -> ChatActionBarReportSpam:
        return ChatActionBarReportSpam.construct(**q)


class ChatActionBarReportUnrelatedLocation(ChatActionBar):
    """
    The chat is a location-based supergroup, which can be reported as having unrelated location using the method reportChat with the reason chatReportReasonUnrelatedLocation
    
    """

    ID: str = Field("chatActionBarReportUnrelatedLocation", alias="@type")

    @staticmethod
    def read(q: dict) -> ChatActionBarReportUnrelatedLocation:
        return ChatActionBarReportUnrelatedLocation.construct(**q)


class ChatActionBarSharePhoneNumber(ChatActionBar):
    """
    The chat is a private or secret chat with a mutual contact and the user's phone number can be shared with the other user using the method sharePhoneNumber
    
    """

    ID: str = Field("chatActionBarSharePhoneNumber", alias="@type")

    @staticmethod
    def read(q: dict) -> ChatActionBarSharePhoneNumber:
        return ChatActionBarSharePhoneNumber.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class RequestAuthenticationPasswordRecovery(BaseObject):
    """
    Requests to send a password recovery code to an email address that was previously set up. Works only when the current authorization state is authorizationStateWaitPassword
    
    """

    ID: str = Field("requestAuthenticationPasswordRecovery", alias="@type")

    @staticmethod
    def read(q: dict) -> RequestAuthenticationPasswordRecovery:
        return RequestAuthenticationPasswordRecovery.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject
from ..types import InputPassportElement


class SetPassportElement(BaseObject):
    """
    Adds an element to the user's Telegram Passport. May return an error with a message "PHONE_VERIFICATION_NEEDED" or "EMAIL_VERIFICATION_NEEDED" if the chosen phone number or the chosen email address must be verified first
    
    Params:
        element (:class:`InputPassportElement`)
            Input Telegram Passport element
        
        password (:class:`str`)
            Password of the current user
        
    """

    ID: str = Field("setPassportElement", alias="@type")
    element: InputPassportElement
    password: str

    @staticmethod
    def read(q: dict) -> SetPassportElement:
        return SetPassportElement.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class PhoneNumberAuthenticationSettings(BaseObject):
    """
    Contains settings for the authentication of the user's phone number
    
    Params:
        allow_flash_call (:class:`bool`)
            Pass true if the authentication code may be sent via flash call to the specified phone number
        
        is_current_phone_number (:class:`bool`)
            Pass true if the authenticated phone number is used on the current device
        
        allow_sms_retriever_api (:class:`bool`)
            For official applications only. True, if the application can use Android SMS Retriever API (requires Google Play Services >= 10.2) to automatically receive the authentication code from the SMS. See https://developers.google.com/identity/sms-retriever/ for more details
        
    """

    ID: str = Field("phoneNumberAuthenticationSettings", alias="@type")
    allow_flash_call: bool
    is_current_phone_number: bool
    allow_sms_retriever_api: bool

    @staticmethod
    def read(q: dict) -> PhoneNumberAuthenticationSettings:
        return PhoneNumberAuthenticationSettings.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject
from ..types import FormattedText


class GetWebPagePreview(BaseObject):
    """
    Returns a web page preview by the text of the message. Do not call this function too often. Returns a 404 error if the web page has no preview
    
    Params:
        text (:class:`FormattedText`)
            Message text with formatting
        
    """

    ID: str = Field("getWebPagePreview", alias="@type")
    text: FormattedText

    @staticmethod
    def read(q: dict) -> GetWebPagePreview:
        return GetWebPagePreview.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject
from ..types import FormattedText


class ParseMarkdown(BaseObject):
    """
    Parses Markdown entities in a human-friendly format, ignoring markup errors. Can be called synchronously
    
    Params:
        text (:class:`FormattedText`)
            The text to parse. For example, "__italic__ ~~strikethrough~~ **bold** `code` ```pre``` __[italic__ text_url](telegram.org) __italic**bold italic__bold**"
        
    """

    ID: str = Field("parseMarkdown", alias="@type")
    text: FormattedText

    @staticmethod
    def read(q: dict) -> ParseMarkdown:
        return ParseMarkdown.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class AddLogMessage(BaseObject):
    """
    Adds a message to TDLib internal log. Can be called synchronously
    
    Params:
        verbosity_level (:class:`int`)
            The minimum verbosity level needed for the message to be logged; 0-1023
        
        text (:class:`str`)
            Text of a message to log
        
    """

    ID: str = Field("addLogMessage", alias="@type")
    verbosity_level: int
    text: str

    @staticmethod
    def read(q: dict) -> AddLogMessage:
        return AddLogMessage.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class GetCountryCode(BaseObject):
    """
    Uses the current IP address to find the current country. Returns two-letter ISO 3166-1 alpha-2 country code. Can be called before authorization
    
    """

    ID: str = Field("getCountryCode", alias="@type")

    @staticmethod
    def read(q: dict) -> GetCountryCode:
        return GetCountryCode.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from .bot_command import BotCommand
from ..base_object import BaseObject


class BotInfo(BaseObject):
    """
    Provides information about a bot and its supported commands
    
    Params:
        param_description (:class:`str`)
            Long description shown on the user info page
        
        commands (:obj:`list[BotCommand]`)
            A list of commands supported by the bot
        
    """

    ID: str = Field("botInfo", alias="@type")
    param_description: str
    commands: list[BotCommand]

    @staticmethod
    def read(q: dict) -> BotInfo:
        return BotInfo.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class ReportSupergroupSpam(BaseObject):
    """
    Reports some messages from a user in a supergroup as spam; requires administrator rights in the supergroup
    
    Params:
        supergroup_id (:class:`int`)
            Supergroup identifier
        
        user_id (:class:`int`)
            User identifier
        
        message_ids (:obj:`list[int]`)
            Identifiers of messages sent in the supergroup by the user. This list must be non-empty
        
    """

    ID: str = Field("reportSupergroupSpam", alias="@type")
    supergroup_id: int
    user_id: int
    message_ids: list[int]

    @staticmethod
    def read(q: dict) -> ReportSupergroupSpam:
        return ReportSupergroupSpam.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from .message import Message
from .message_sender import MessageSender
from .push_message_content import PushMessageContent
from ..base_object import BaseObject


class NotificationType(BaseObject):
    """
    Contains detailed information about a notification
    
    """

    ID: str = Field("notificationType", alias="@type")


class NotificationTypeNewCall(NotificationType):
    """
    New call was received
    
    Params:
        call_id (:class:`int`)
            Call identifier
        
    """

    ID: str = Field("notificationTypeNewCall", alias="@type")
    call_id: int

    @staticmethod
    def read(q: dict) -> NotificationTypeNewCall:
        return NotificationTypeNewCall.construct(**q)


class NotificationTypeNewMessage(NotificationType):
    """
    New message was received
    
    Params:
        message (:class:`Message`)
            The message
        
    """

    ID: str = Field("notificationTypeNewMessage", alias="@type")
    message: Message

    @staticmethod
    def read(q: dict) -> NotificationTypeNewMessage:
        return NotificationTypeNewMessage.construct(**q)


class NotificationTypeNewPushMessage(NotificationType):
    """
    New message was received through a push notification
    
    Params:
        message_id (:class:`int`)
            The message identifier. The message will not be available in the chat history, but the ID can be used in viewMessages, or as reply_to_message_id
        
        sender (:class:`MessageSender`)
            The sender of the message. Corresponding user or chat may be inaccessible
        
        sender_name (:class:`str`)
            Name of the sender
        
        is_outgoing (:class:`bool`)
            True, if the message is outgoing
        
        content (:class:`PushMessageContent`)
            Push message content
        
    """

    ID: str = Field("notificationTypeNewPushMessage", alias="@type")
    message_id: int
    sender: MessageSender
    sender_name: str
    is_outgoing: bool
    content: PushMessageContent

    @staticmethod
    def read(q: dict) -> NotificationTypeNewPushMessage:
        return NotificationTypeNewPushMessage.construct(**q)


class NotificationTypeNewSecretChat(NotificationType):
    """
    New secret chat was created
    
    """

    ID: str = Field("notificationTypeNewSecretChat", alias="@type")

    @staticmethod
    def read(q: dict) -> NotificationTypeNewSecretChat:
        return NotificationTypeNewSecretChat.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from .file import File
from ..base_object import BaseObject


class VoiceNote(BaseObject):
    """
    Describes a voice note. The voice note must be encoded with the Opus codec, and stored inside an OGG container. Voice notes can have only a single audio channel
    
    Params:
        duration (:class:`int`)
            Duration of the voice note, in seconds; as defined by the sender
        
        waveform (:class:`str`)
            A waveform representation of the voice note in 5-bit format
        
        mime_type (:class:`str`)
            MIME type of the file; as defined by the sender
        
        voice (:class:`File`)
            File containing the voice note
        
    """

    ID: str = Field("voiceNote", alias="@type")
    duration: int
    waveform: str
    mime_type: str
    voice: File

    @staticmethod
    def read(q: dict) -> VoiceNote:
        return VoiceNote.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject
from ..types import CallProtocol


class AcceptCall(BaseObject):
    """
    Accepts an incoming call
    
    Params:
        call_id (:class:`int`)
            Call identifier
        
        protocol (:class:`CallProtocol`)
            Description of the call protocols supported by the application
        
    """

    ID: str = Field("acceptCall", alias="@type")
    call_id: int
    protocol: CallProtocol

    @staticmethod
    def read(q: dict) -> AcceptCall:
        return AcceptCall.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class TextEntityType(BaseObject):
    """
    Represents a part of the text which must be formatted differently
    
    """

    ID: str = Field("textEntityType", alias="@type")


class TextEntityTypeBankCardNumber(TextEntityType):
    """
    A bank card number. The getBankCardInfo method can be used to get information about the bank card
    
    """

    ID: str = Field("textEntityTypeBankCardNumber", alias="@type")

    @staticmethod
    def read(q: dict) -> TextEntityTypeBankCardNumber:
        return TextEntityTypeBankCardNumber.construct(**q)


class TextEntityTypeBold(TextEntityType):
    """
    A bold text
    
    """

    ID: str = Field("textEntityTypeBold", alias="@type")

    @staticmethod
    def read(q: dict) -> TextEntityTypeBold:
        return TextEntityTypeBold.construct(**q)


class TextEntityTypeBotCommand(TextEntityType):
    """
    A bot command, beginning with "/". This shouldn't be highlighted if there are no bots in the chat
    
    """

    ID: str = Field("textEntityTypeBotCommand", alias="@type")

    @staticmethod
    def read(q: dict) -> TextEntityTypeBotCommand:
        return TextEntityTypeBotCommand.construct(**q)


class TextEntityTypeCashtag(TextEntityType):
    """
    A cashtag text, beginning with "$" and consisting of capital english letters (i.e. "$USD")
    
    """

    ID: str = Field("textEntityTypeCashtag", alias="@type")

    @staticmethod
    def read(q: dict) -> TextEntityTypeCashtag:
        return TextEntityTypeCashtag.construct(**q)


class TextEntityTypeCode(TextEntityType):
    """
    Text that must be formatted as if inside a code HTML tag
    
    """

    ID: str = Field("textEntityTypeCode", alias="@type")

    @staticmethod
    def read(q: dict) -> TextEntityTypeCode:
        return TextEntityTypeCode.construct(**q)


class TextEntityTypeEmailAddress(TextEntityType):
    """
    An email address
    
    """

    ID: str = Field("textEntityTypeEmailAddress", alias="@type")

    @staticmethod
    def read(q: dict) -> TextEntityTypeEmailAddress:
        return TextEntityTypeEmailAddress.construct(**q)


class TextEntityTypeHashtag(TextEntityType):
    """
    A hashtag text, beginning with "#"
    
    """

    ID: str = Field("textEntityTypeHashtag", alias="@type")

    @staticmethod
    def read(q: dict) -> TextEntityTypeHashtag:
        return TextEntityTypeHashtag.construct(**q)


class TextEntityTypeItalic(TextEntityType):
    """
    An italic text
    
    """

    ID: str = Field("textEntityTypeItalic", alias="@type")

    @staticmethod
    def read(q: dict) -> TextEntityTypeItalic:
        return TextEntityTypeItalic.construct(**q)


class TextEntityTypeMention(TextEntityType):
    """
    A mention of a user by their username
    
    """

    ID: str = Field("textEntityTypeMention", alias="@type")

    @staticmethod
    def read(q: dict) -> TextEntityTypeMention:
        return TextEntityTypeMention.construct(**q)


class TextEntityTypeMentionName(TextEntityType):
    """
    A text shows instead of a raw mention of the user (e.g., when the user has no username)
    
    Params:
        user_id (:class:`int`)
            Identifier of the mentioned user
        
    """

    ID: str = Field("textEntityTypeMentionName", alias="@type")
    user_id: int

    @staticmethod
    def read(q: dict) -> TextEntityTypeMentionName:
        return TextEntityTypeMentionName.construct(**q)


class TextEntityTypePhoneNumber(TextEntityType):
    """
    A phone number
    
    """

    ID: str = Field("textEntityTypePhoneNumber", alias="@type")

    @staticmethod
    def read(q: dict) -> TextEntityTypePhoneNumber:
        return TextEntityTypePhoneNumber.construct(**q)


class TextEntityTypePre(TextEntityType):
    """
    Text that must be formatted as if inside a pre HTML tag
    
    """

    ID: str = Field("textEntityTypePre", alias="@type")

    @staticmethod
    def read(q: dict) -> TextEntityTypePre:
        return TextEntityTypePre.construct(**q)


class TextEntityTypePreCode(TextEntityType):
    """
    Text that must be formatted as if inside pre, and code HTML tags
    
    Params:
        language (:class:`str`)
            Programming language of the code; as defined by the sender
        
    """

    ID: str = Field("textEntityTypePreCode", alias="@type")
    language: str

    @staticmethod
    def read(q: dict) -> TextEntityTypePreCode:
        return TextEntityTypePreCode.construct(**q)


class TextEntityTypeStrikethrough(TextEntityType):
    """
    A strikethrough text
    
    """

    ID: str = Field("textEntityTypeStrikethrough", alias="@type")

    @staticmethod
    def read(q: dict) -> TextEntityTypeStrikethrough:
        return TextEntityTypeStrikethrough.construct(**q)


class TextEntityTypeTextUrl(TextEntityType):
    """
    A text description shown instead of a raw URL
    
    Params:
        url (:class:`str`)
            HTTP or tg:// URL to be opened when the link is clicked
        
    """

    ID: str = Field("textEntityTypeTextUrl", alias="@type")
    url: str

    @staticmethod
    def read(q: dict) -> TextEntityTypeTextUrl:
        return TextEntityTypeTextUrl.construct(**q)


class TextEntityTypeUnderline(TextEntityType):
    """
    An underlined text
    
    """

    ID: str = Field("textEntityTypeUnderline", alias="@type")

    @staticmethod
    def read(q: dict) -> TextEntityTypeUnderline:
        return TextEntityTypeUnderline.construct(**q)


class TextEntityTypeUrl(TextEntityType):
    """
    An HTTP URL
    
    """

    ID: str = Field("textEntityTypeUrl", alias="@type")

    @staticmethod
    def read(q: dict) -> TextEntityTypeUrl:
        return TextEntityTypeUrl.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class ChatEventLogFilters(BaseObject):
    """
    Represents a set of filters used to obtain a chat event log
    
    Params:
        message_edits (:class:`bool`)
            True, if message edits should be returned
        
        message_deletions (:class:`bool`)
            True, if message deletions should be returned
        
        message_pins (:class:`bool`)
            True, if pin/unpin events should be returned
        
        member_joins (:class:`bool`)
            True, if members joining events should be returned
        
        member_leaves (:class:`bool`)
            True, if members leaving events should be returned
        
        member_invites (:class:`bool`)
            True, if invited member events should be returned
        
        member_promotions (:class:`bool`)
            True, if member promotion/demotion events should be returned
        
        member_restrictions (:class:`bool`)
            True, if member restricted/unrestricted/banned/unbanned events should be returned
        
        info_changes (:class:`bool`)
            True, if changes in chat information should be returned
        
        setting_changes (:class:`bool`)
            True, if changes in chat settings should be returned
        
        invite_link_changes (:class:`bool`)
            True, if changes to invite links should be returned
        
        voice_chat_changes (:class:`bool`)
            True, if voice chat actions should be returned
        
    """

    ID: str = Field("chatEventLogFilters", alias="@type")
    message_edits: bool
    message_deletions: bool
    message_pins: bool
    member_joins: bool
    member_leaves: bool
    member_invites: bool
    member_promotions: bool
    member_restrictions: bool
    info_changes: bool
    setting_changes: bool
    invite_link_changes: bool
    voice_chat_changes: bool

    @staticmethod
    def read(q: dict) -> ChatEventLogFilters:
        return ChatEventLogFilters.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class GetChatStatistics(BaseObject):
    """
    Returns detailed statistics about a chat. Currently this method can be used only for supergroups and channels. Can be used only if SupergroupFullInfo.can_get_statistics == true
    
    Params:
        chat_id (:class:`int`)
            Chat identifier
        
        is_dark (:class:`bool`)
            Pass true if a dark theme is used by the application
        
    """

    ID: str = Field("getChatStatistics", alias="@type")
    chat_id: int
    is_dark: bool

    @staticmethod
    def read(q: dict) -> GetChatStatistics:
        return GetChatStatistics.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class GetCurrentState(BaseObject):
    """
    Returns all updates needed to restore current TDLib state, i.e. all actual UpdateAuthorizationState/UpdateUser/UpdateNewChat and others. This is especially useful if TDLib is run in a separate process. Can be called before initialization
    
    """

    ID: str = Field("getCurrentState", alias="@type")

    @staticmethod
    def read(q: dict) -> GetCurrentState:
        return GetCurrentState.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from .local_file import LocalFile
from .remote_file import RemoteFile
from ..base_object import BaseObject


class File(BaseObject):
    """
    Represents a file
    
    Params:
        id (:class:`int`)
            Unique file identifier
        
        size (:class:`int`)
            File size; 0 if unknown
        
        expected_size (:class:`int`)
            Expected file size in case the exact file size is unknown, but an approximate size is known. Can be used to show download/upload progress
        
        local (:class:`LocalFile`)
            Information about the local copy of the file
        
        remote (:class:`RemoteFile`)
            Information about the remote copy of the file
        
    """

    ID: str = Field("file", alias="@type")
    id: int
    size: int
    expected_size: int
    local: LocalFile
    remote: RemoteFile

    @staticmethod
    def read(q: dict) -> File:
        return File.construct(**q)



from __future__ import annotations

import logging
from enum import Enum
from typing import Any, Dict, Optional, Type

from pydantic import BaseConfig, BaseModel, Field

logger = logging.getLogger('BaseObject')


class BaseObject(BaseModel):
    class Config(BaseConfig):
        anystr_strip_whitespace = True
        underscore_attrs_are_private = True
        use_enum_values = True

    _all: Optional[Dict[str, Type[BaseObject]]] = {}
    ID: str = Field(..., alias='@type')
    EXTRA: Optional[dict[str, Any]] = Field({}, alias='@extra')

    @staticmethod
    def read(data: dict):
        if isinstance(data, (list, tuple,)):
            return [BaseObject.read(x) for x in data]

        if not isinstance(data, dict):
            return data

        q_type = data.get('@type')

        if not bool(q_type):
            return data

        q_type = q_type.value if isinstance(q_type, Enum) else q_type
        object_class = BaseObject._all.get(q_type)

        if not bool(object_class):
            logger.error(f'Object class not found for @type={q_type}')
            return data

        processed_data = {}

        for key, value in data.items():
            # Workaround for BaseModel.construct(**kwargs).
            # It doesn't automatically rename fields according to aliases
            if key in ['json', 'filter', 'type', 'hash']:
                key = key + "_"
            elif key == '@extra':
                key = 'EXTRA'

            processed_data[key] = BaseObject.read(value)

        del data

        return object_class.read(processed_data)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class CancelUploadFile(BaseObject):
    """
    Stops the uploading of a file. Supported only for files uploaded by using uploadFile. For other files the behavior is undefined
    
    Params:
        file_id (:class:`int`)
            Identifier of the file to stop uploading
        
    """

    ID: str = Field("cancelUploadFile", alias="@type")
    file_id: int

    @staticmethod
    def read(q: dict) -> CancelUploadFile:
        return CancelUploadFile.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from .t_me_url_type import TMeUrlType
from ..base_object import BaseObject


class TMeUrl(BaseObject):
    """
    Represents a URL linking to an internal Telegram entity
    
    Params:
        url (:class:`str`)
            URL
        
        type_ (:class:`TMeUrlType`)
            Type of the URL
        
    """

    ID: str = Field("tMeUrl", alias="@type")
    url: str
    type_: TMeUrlType = Field(..., alias='type')

    @staticmethod
    def read(q: dict) -> TMeUrl:
        return TMeUrl.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class GetChatHistory(BaseObject):
    """
    Returns messages in a chat. The messages are returned in a reverse chronological order (i.e., in order of decreasing message_id). For optimal performance the number of returned messages is chosen by the library. This is an offline request if only_local is true
    
    Params:
        chat_id (:class:`int`)
            Chat identifier
        
        from_message_id (:class:`int`)
            Identifier of the message starting from which history must be fetched; use 0 to get results from the last message
        
        offset (:class:`int`)
            Specify 0 to get results from exactly the from_message_id or a negative offset up to 99 to get additionally some newer messages
        
        limit (:class:`int`)
            The maximum number of messages to be returned; must be positive and can't be greater than 100. If the offset is negative, the limit must be greater than or equal to -offset. Fewer messages may be returned than specified by the limit, even if the end of the message history has not been reached
        
        only_local (:class:`bool`)
            If true, returns only messages that are available locally without sending network requests
        
    """

    ID: str = Field("getChatHistory", alias="@type")
    chat_id: int
    from_message_id: int
    offset: int
    limit: int
    only_local: bool

    @staticmethod
    def read(q: dict) -> GetChatHistory:
        return GetChatHistory.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

import typing

from pydantic import Field

from .chat_invite_link import ChatInviteLink
from .chat_location import ChatLocation
from .chat_photo import ChatPhoto
from ..base_object import BaseObject


class SupergroupFullInfo(BaseObject):
    """
    Contains full information about a supergroup or channel
    
    Params:
        photo (:class:`ChatPhoto`)
            Chat photo; may be null
        
        param_description (:class:`str`)
            Supergroup or channel description
        
        member_count (:class:`int`)
            Number of members in the supergroup or channel; 0 if unknown
        
        administrator_count (:class:`int`)
            Number of privileged users in the supergroup or channel; 0 if unknown
        
        restricted_count (:class:`int`)
            Number of restricted users in the supergroup; 0 if unknown
        
        banned_count (:class:`int`)
            Number of users banned from chat; 0 if unknown
        
        linked_chat_id (:class:`int`)
            Chat identifier of a discussion group for the channel, or a channel, for which the supergroup is the designated discussion group; 0 if none or unknown
        
        slow_mode_delay (:class:`int`)
            Delay between consecutive sent messages for non-administrator supergroup members, in seconds
        
        slow_mode_delay_expires_in (:class:`float`)
            Time left before next message can be sent in the supergroup, in seconds. An updateSupergroupFullInfo update is not triggered when value of this field changes, but both new and old values are non-zero
        
        can_get_members (:class:`bool`)
            True, if members of the chat can be retrieved
        
        can_set_username (:class:`bool`)
            True, if the chat username can be changed
        
        can_set_sticker_set (:class:`bool`)
            True, if the supergroup sticker set can be changed
        
        can_set_location (:class:`bool`)
            True, if the supergroup location can be changed
        
        can_get_statistics (:class:`bool`)
            True, if the supergroup or channel statistics are available
        
        is_all_history_available (:class:`bool`)
            True, if new chat members will have access to old messages. In public or discussion groups and both public and private channels, old messages are always available, so this option affects only private supergroups without a linked chat. The value of this field is only available for chat administrators
        
        sticker_set_id (:class:`int`)
            Identifier of the supergroup sticker set; 0 if none
        
        location (:class:`ChatLocation`)
            Location to which the supergroup is connected; may be null
        
        invite_link (:class:`ChatInviteLink`)
            Primary invite link for this chat; may be null. For chat administrators with can_invite_users right only
        
        upgraded_from_basic_group_id (:class:`int`)
            Identifier of the basic group from which supergroup was upgraded; 0 if none
        
        upgraded_from_max_message_id (:class:`int`)
            Identifier of the last message in the basic group from which supergroup was upgraded; 0 if none
        
    """

    ID: str = Field("supergroupFullInfo", alias="@type")
    photo: typing.Optional[ChatPhoto] = None
    param_description: str
    member_count: int
    administrator_count: int
    restricted_count: int
    banned_count: int
    linked_chat_id: int
    slow_mode_delay: int
    slow_mode_delay_expires_in: float
    can_get_members: bool
    can_set_username: bool
    can_set_sticker_set: bool
    can_set_location: bool
    can_get_statistics: bool
    is_all_history_available: bool
    sticker_set_id: int
    location: typing.Optional[ChatLocation] = None
    invite_link: typing.Optional[ChatInviteLink] = None
    upgraded_from_basic_group_id: int
    upgraded_from_max_message_id: int

    @staticmethod
    def read(q: dict) -> SupergroupFullInfo:
        return SupergroupFullInfo.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class LoadGroupCallParticipants(BaseObject):
    """
    Loads more group call participants. The loaded participants will be received through updates. Use the field groupCall.loaded_all_participants to check whether all participants has already been loaded
    
    Params:
        group_call_id (:class:`int`)
            Group call identifier. The group call must be previously received through getGroupCall and must be joined or being joined
        
        limit (:class:`int`)
            Maximum number of participants to load
        
    """

    ID: str = Field("loadGroupCallParticipants", alias="@type")
    group_call_id: int
    limit: int

    @staticmethod
    def read(q: dict) -> LoadGroupCallParticipants:
        return LoadGroupCallParticipants.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from .storage_statistics_by_file_type import StorageStatisticsByFileType
from ..base_object import BaseObject


class StorageStatisticsByChat(BaseObject):
    """
    Contains the storage usage statistics for a specific chat
    
    Params:
        chat_id (:class:`int`)
            Chat identifier; 0 if none
        
        size (:class:`int`)
            Total size of the files in the chat
        
        count (:class:`int`)
            Total number of files in the chat
        
        by_file_type (:obj:`list[StorageStatisticsByFileType]`)
            Statistics split by file types
        
    """

    ID: str = Field("storageStatisticsByChat", alias="@type")
    chat_id: int
    size: int
    count: int
    by_file_type: list[StorageStatisticsByFileType]

    @staticmethod
    def read(q: dict) -> StorageStatisticsByChat:
        return StorageStatisticsByChat.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class GetEmojiSuggestionsUrl(BaseObject):
    """
    Returns an HTTP URL which can be used to automatically log in to the translation platform and suggest new emoji replacements. The URL will be valid for 30 seconds after generation
    
    Params:
        language_code (:class:`str`)
            Language code for which the emoji replacements will be suggested
        
    """

    ID: str = Field("getEmojiSuggestionsUrl", alias="@type")
    language_code: str

    @staticmethod
    def read(q: dict) -> GetEmojiSuggestionsUrl:
        return GetEmojiSuggestionsUrl.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class TestSquareInt(BaseObject):
    """
    Returns the squared received number; for testing only. This is an offline method. Can be called before authorization
    
    Params:
        x (:class:`int`)
            Number to square
        
    """

    ID: str = Field("testSquareInt", alias="@type")
    x: int

    @staticmethod
    def read(q: dict) -> TestSquareInt:
        return TestSquareInt.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

import typing

from pydantic import Field

from .date import Date
from .dated_file import DatedFile
from ..base_object import BaseObject


class IdentityDocument(BaseObject):
    """
    An identity document
    
    Params:
        number (:class:`str`)
            Document number; 1-24 characters
        
        expiry_date (:class:`Date`)
            Document expiry date; may be null
        
        front_side (:class:`DatedFile`)
            Front side of the document
        
        reverse_side (:class:`DatedFile`)
            Reverse side of the document; only for driver license and identity card
        
        selfie (:class:`DatedFile`)
            Selfie with the document; may be null
        
        translation (:obj:`list[DatedFile]`)
            List of files containing a certified English translation of the document
        
    """

    ID: str = Field("identityDocument", alias="@type")
    number: str = Field(..., min_length=1, max_length=24)
    expiry_date: typing.Optional[Date] = None
    front_side: DatedFile
    reverse_side: DatedFile
    selfie: typing.Optional[DatedFile] = None
    translation: list[DatedFile]

    @staticmethod
    def read(q: dict) -> IdentityDocument:
        return IdentityDocument.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class CloseChat(BaseObject):
    """
    Informs TDLib that the chat is closed by the user. Many useful activities depend on the chat being opened or closed
    
    Params:
        chat_id (:class:`int`)
            Chat identifier
        
    """

    ID: str = Field("closeChat", alias="@type")
    chat_id: int

    @staticmethod
    def read(q: dict) -> CloseChat:
        return CloseChat.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class CheckPhoneNumberConfirmationCode(BaseObject):
    """
    Checks phone number confirmation code
    
    Params:
        code (:class:`str`)
            The phone number confirmation code
        
    """

    ID: str = Field("checkPhoneNumberConfirmationCode", alias="@type")
    code: str

    @staticmethod
    def read(q: dict) -> CheckPhoneNumberConfirmationCode:
        return CheckPhoneNumberConfirmationCode.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject
from ..types import ChatEventLogFilters


class GetChatEventLog(BaseObject):
    """
    Returns a list of service actions taken by chat members and administrators in the last 48 hours. Available only for supergroups and channels. Requires administrator rights. Returns results in reverse chronological order (i. e., in order of decreasing event_id)
    
    Params:
        chat_id (:class:`int`)
            Chat identifier
        
        query (:class:`str`)
            Search query by which to filter events
        
        from_event_id (:class:`int`)
            Identifier of an event from which to return results. Use 0 to get results from the latest events
        
        limit (:class:`int`)
            The maximum number of events to return; up to 100
        
        filters (:class:`ChatEventLogFilters`)
            The types of events to return. By default, all types will be returned
        
        user_ids (:obj:`list[int]`)
            User identifiers by which to filter events. By default, events relating to all users will be returned
        
    """

    ID: str = Field("getChatEventLog", alias="@type")
    chat_id: int
    query: str
    from_event_id: int
    limit: int
    filters: ChatEventLogFilters
    user_ids: list[int]

    @staticmethod
    def read(q: dict) -> GetChatEventLog:
        return GetChatEventLog.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class PageBlockHorizontalAlignment(BaseObject):
    """
    Describes a horizontal alignment of a table cell content
    
    """

    ID: str = Field("pageBlockHorizontalAlignment", alias="@type")


class PageBlockHorizontalAlignmentCenter(PageBlockHorizontalAlignment):
    """
    The content should be center-aligned
    
    """

    ID: str = Field("pageBlockHorizontalAlignmentCenter", alias="@type")

    @staticmethod
    def read(q: dict) -> PageBlockHorizontalAlignmentCenter:
        return PageBlockHorizontalAlignmentCenter.construct(**q)


class PageBlockHorizontalAlignmentLeft(PageBlockHorizontalAlignment):
    """
    The content should be left-aligned
    
    """

    ID: str = Field("pageBlockHorizontalAlignmentLeft", alias="@type")

    @staticmethod
    def read(q: dict) -> PageBlockHorizontalAlignmentLeft:
        return PageBlockHorizontalAlignmentLeft.construct(**q)


class PageBlockHorizontalAlignmentRight(PageBlockHorizontalAlignment):
    """
    The content should be right-aligned
    
    """

    ID: str = Field("pageBlockHorizontalAlignmentRight", alias="@type")

    @staticmethod
    def read(q: dict) -> PageBlockHorizontalAlignmentRight:
        return PageBlockHorizontalAlignmentRight.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class Close(BaseObject):
    """
    Closes the TDLib instance. All databases will be flushed to disk and properly closed. After the close completes, updateAuthorizationState with authorizationStateClosed will be sent. Can be called before initialization
    
    """

    ID: str = Field("close", alias="@type")

    @staticmethod
    def read(q: dict) -> Close:
        return Close.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class TopChatCategory(BaseObject):
    """
    Represents the categories of chats for which a list of frequently used chats can be retrieved
    
    """

    ID: str = Field("topChatCategory", alias="@type")


class TopChatCategoryBots(TopChatCategory):
    """
    A category containing frequently used private chats with bot users
    
    """

    ID: str = Field("topChatCategoryBots", alias="@type")

    @staticmethod
    def read(q: dict) -> TopChatCategoryBots:
        return TopChatCategoryBots.construct(**q)


class TopChatCategoryCalls(TopChatCategory):
    """
    A category containing frequently used chats used for calls
    
    """

    ID: str = Field("topChatCategoryCalls", alias="@type")

    @staticmethod
    def read(q: dict) -> TopChatCategoryCalls:
        return TopChatCategoryCalls.construct(**q)


class TopChatCategoryChannels(TopChatCategory):
    """
    A category containing frequently used channels
    
    """

    ID: str = Field("topChatCategoryChannels", alias="@type")

    @staticmethod
    def read(q: dict) -> TopChatCategoryChannels:
        return TopChatCategoryChannels.construct(**q)


class TopChatCategoryForwardChats(TopChatCategory):
    """
    A category containing frequently used chats used to forward messages
    
    """

    ID: str = Field("topChatCategoryForwardChats", alias="@type")

    @staticmethod
    def read(q: dict) -> TopChatCategoryForwardChats:
        return TopChatCategoryForwardChats.construct(**q)


class TopChatCategoryGroups(TopChatCategory):
    """
    A category containing frequently used basic groups and supergroups
    
    """

    ID: str = Field("topChatCategoryGroups", alias="@type")

    @staticmethod
    def read(q: dict) -> TopChatCategoryGroups:
        return TopChatCategoryGroups.construct(**q)


class TopChatCategoryInlineBots(TopChatCategory):
    """
    A category containing frequently used chats with inline bots sorted by their usage in inline mode
    
    """

    ID: str = Field("topChatCategoryInlineBots", alias="@type")

    @staticmethod
    def read(q: dict) -> TopChatCategoryInlineBots:
        return TopChatCategoryInlineBots.construct(**q)


class TopChatCategoryUsers(TopChatCategory):
    """
    A category containing frequently used private chats with non-bot users
    
    """

    ID: str = Field("topChatCategoryUsers", alias="@type")

    @staticmethod
    def read(q: dict) -> TopChatCategoryUsers:
        return TopChatCategoryUsers.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class CanTransferOwnershipResult(BaseObject):
    """
    Represents result of checking whether the current session can be used to transfer a chat ownership to another user
    
    """

    ID: str = Field("canTransferOwnershipResult", alias="@type")


class CanTransferOwnershipResultOk(CanTransferOwnershipResult):
    """
    The session can be used
    
    """

    ID: str = Field("canTransferOwnershipResultOk", alias="@type")

    @staticmethod
    def read(q: dict) -> CanTransferOwnershipResultOk:
        return CanTransferOwnershipResultOk.construct(**q)


class CanTransferOwnershipResultPasswordNeeded(CanTransferOwnershipResult):
    """
    The 2-step verification needs to be enabled first
    
    """

    ID: str = Field("canTransferOwnershipResultPasswordNeeded", alias="@type")

    @staticmethod
    def read(q: dict) -> CanTransferOwnershipResultPasswordNeeded:
        return CanTransferOwnershipResultPasswordNeeded.construct(**q)


class CanTransferOwnershipResultPasswordTooFresh(CanTransferOwnershipResult):
    """
    The 2-step verification was enabled recently, user needs to wait
    
    Params:
        retry_after (:class:`int`)
            Time left before the session can be used to transfer ownership of a chat, in seconds
        
    """

    ID: str = Field("canTransferOwnershipResultPasswordTooFresh", alias="@type")
    retry_after: int

    @staticmethod
    def read(q: dict) -> CanTransferOwnershipResultPasswordTooFresh:
        return CanTransferOwnershipResultPasswordTooFresh.construct(**q)


class CanTransferOwnershipResultSessionTooFresh(CanTransferOwnershipResult):
    """
    The session was created recently, user needs to wait
    
    Params:
        retry_after (:class:`int`)
            Time left before the session can be used to transfer ownership of a chat, in seconds
        
    """

    ID: str = Field("canTransferOwnershipResultSessionTooFresh", alias="@type")
    retry_after: int

    @staticmethod
    def read(q: dict) -> CanTransferOwnershipResultSessionTooFresh:
        return CanTransferOwnershipResultSessionTooFresh.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from .passport_element import PassportElement
from .passport_element_error import PassportElementError
from ..base_object import BaseObject


class PassportElementsWithErrors(BaseObject):
    """
    Contains information about a Telegram Passport elements and corresponding errors
    
    Params:
        elements (:obj:`list[PassportElement]`)
            Telegram Passport elements
        
        errors (:obj:`list[PassportElementError]`)
            Errors in the elements that are already available
        
    """

    ID: str = Field("passportElementsWithErrors", alias="@type")
    elements: list[PassportElement]
    errors: list[PassportElementError]

    @staticmethod
    def read(q: dict) -> PassportElementsWithErrors:
        return PassportElementsWithErrors.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class ChatInviteLink(BaseObject):
    """
    Contains a chat invite link
    
    Params:
        invite_link (:class:`str`)
            Chat invite link
        
        creator_user_id (:class:`int`)
            User identifier of an administrator created the link
        
        date (:class:`int`)
            Point in time (Unix timestamp) when the link was created
        
        edit_date (:class:`int`)
            Point in time (Unix timestamp) when the link was last edited; 0 if never or unknown
        
        expire_date (:class:`int`)
            Point in time (Unix timestamp) when the link will expire; 0 if never
        
        member_limit (:class:`int`)
            Maximum number of members, which can join the chat using the link simultaneously; 0 if not limited
        
        member_count (:class:`int`)
            Number of chat members, which joined the chat using the link
        
        is_primary (:class:`bool`)
            True, if the link is primary. Primary invite link can't have expire date or usage limit. There is exactly one primary invite link for each administrator with can_invite_users right at a given time
        
        is_revoked (:class:`bool`)
            True, if the link was revoked
        
    """

    ID: str = Field("chatInviteLink", alias="@type")
    invite_link: str
    creator_user_id: int
    date: int
    edit_date: int
    expire_date: int
    member_limit: int
    member_count: int
    is_primary: bool
    is_revoked: bool

    @staticmethod
    def read(q: dict) -> ChatInviteLink:
        return ChatInviteLink.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

import typing

from pydantic import Field

from .photo import Photo
from ..base_object import BaseObject


class PageBlockRelatedArticle(BaseObject):
    """
    Contains information about a related article
    
    Params:
        url (:class:`str`)
            Related article URL
        
        title (:class:`str`)
            Article title; may be empty
        
        param_description (:class:`str`)
            Article description; may be empty
        
        photo (:class:`Photo`)
            Article photo; may be null
        
        author (:class:`str`)
            Article author; may be empty
        
        publish_date (:class:`int`)
            Point in time (Unix timestamp) when the article was published; 0 if unknown
        
    """

    ID: str = Field("pageBlockRelatedArticle", alias="@type")
    url: str
    title: str
    param_description: str
    photo: typing.Optional[Photo] = None
    author: str
    publish_date: int

    @staticmethod
    def read(q: dict) -> PageBlockRelatedArticle:
        return PageBlockRelatedArticle.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject
from ..types import Location


class SetLocation(BaseObject):
    """
    Changes the location of the current user. Needs to be called if GetOption("is_location_visible") is true and location changes for more than 1 kilometer
    
    Params:
        location (:class:`Location`)
            The new location of the user
        
    """

    ID: str = Field("setLocation", alias="@type")
    location: Location

    @staticmethod
    def read(q: dict) -> SetLocation:
        return SetLocation.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from .message_sender import MessageSender
from ..base_object import BaseObject


class GroupCallParticipant(BaseObject):
    """
    Represents a group call participant
    
    Params:
        participant (:class:`MessageSender`)
            Identifier of the group call participant
        
        source (:class:`int`)
            User's synchronization source
        
        bio (:class:`str`)
            The participant user's bio or the participant chat's description
        
        is_current_user (:class:`bool`)
            True, if the participant is the current user
        
        is_speaking (:class:`bool`)
            True, if the participant is speaking as set by setGroupCallParticipantIsSpeaking
        
        is_hand_raised (:class:`bool`)
            True, if the participant hand is raised
        
        can_be_muted_for_all_users (:class:`bool`)
            True, if the current user can mute the participant for all other group call participants
        
        can_be_unmuted_for_all_users (:class:`bool`)
            True, if the current user can allow the participant to unmute themself or unmute the participant (if the participant is the current user)
        
        can_be_muted_for_current_user (:class:`bool`)
            True, if the current user can mute the participant only for self
        
        can_be_unmuted_for_current_user (:class:`bool`)
            True, if the current user can unmute the participant for self
        
        is_muted_for_all_users (:class:`bool`)
            True, if the participant is muted for all users
        
        is_muted_for_current_user (:class:`bool`)
            True, if the participant is muted for the current user
        
        can_unmute_self (:class:`bool`)
            True, if the participant is muted for all users, but can unmute themself
        
        volume_level (:class:`int`)
            Participant's volume level; 1-20000 in hundreds of percents
        
        order (:class:`str`)
            User's order in the group call participant list. Orders must be compared lexicographically. The bigger is order, the higher is user in the list. If order is empty, the user must be removed from the participant list
        
    """

    ID: str = Field("groupCallParticipant", alias="@type")
    participant: MessageSender
    source: int
    bio: str
    is_current_user: bool
    is_speaking: bool
    is_hand_raised: bool
    can_be_muted_for_all_users: bool
    can_be_unmuted_for_all_users: bool
    can_be_muted_for_current_user: bool
    can_be_unmuted_for_current_user: bool
    is_muted_for_all_users: bool
    is_muted_for_current_user: bool
    can_unmute_self: bool
    volume_level: int
    order: str

    @staticmethod
    def read(q: dict) -> GroupCallParticipant:
        return GroupCallParticipant.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class DeleteLanguagePack(BaseObject):
    """
    Deletes all information about a language pack in the current localization target. The language pack which is currently in use (including base language pack) or is being synchronized can't be deleted. Can be called before authorization
    
    Params:
        language_pack_id (:class:`str`)
            Identifier of the language pack to delete
        
    """

    ID: str = Field("deleteLanguagePack", alias="@type")
    language_pack_id: str

    @staticmethod
    def read(q: dict) -> DeleteLanguagePack:
        return DeleteLanguagePack.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class DisconnectWebsite(BaseObject):
    """
    Disconnects website from the current user's Telegram account
    
    Params:
        website_id (:class:`int`)
            Website identifier
        
    """

    ID: str = Field("disconnectWebsite", alias="@type")
    website_id: int

    @staticmethod
    def read(q: dict) -> DisconnectWebsite:
        return DisconnectWebsite.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class ConnectedWebsite(BaseObject):
    """
    Contains information about one website the current user is logged in with Telegram
    
    Params:
        id (:class:`int`)
            Website identifier
        
        domain_name (:class:`str`)
            The domain name of the website
        
        bot_user_id (:class:`int`)
            User identifier of a bot linked with the website
        
        browser (:class:`str`)
            The version of a browser used to log in
        
        platform (:class:`str`)
            Operating system the browser is running on
        
        log_in_date (:class:`int`)
            Point in time (Unix timestamp) when the user was logged in
        
        last_active_date (:class:`int`)
            Point in time (Unix timestamp) when obtained authorization was last used
        
        ip (:class:`str`)
            IP address from which the user was logged in, in human-readable format
        
        location (:class:`str`)
            Human-readable description of a country and a region, from which the user was logged in, based on the IP address
        
    """

    ID: str = Field("connectedWebsite", alias="@type")
    id: int
    domain_name: str
    bot_user_id: int
    browser: str
    platform: str
    log_in_date: int
    last_active_date: int
    ip: str
    location: str

    @staticmethod
    def read(q: dict) -> ConnectedWebsite:
        return ConnectedWebsite.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from .file import File
from ..base_object import BaseObject


class DatedFile(BaseObject):
    """
    File with the date it was uploaded
    
    Params:
        file (:class:`File`)
            The file
        
        date (:class:`int`)
            Point in time (Unix timestamp) when the file was uploaded
        
    """

    ID: str = Field("datedFile", alias="@type")
    file: File
    date: int

    @staticmethod
    def read(q: dict) -> DatedFile:
        return DatedFile.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class CustomRequestResult(BaseObject):
    """
    Contains the result of a custom request
    
    Params:
        result (:class:`str`)
            A JSON-serialized result
        
    """

    ID: str = Field("customRequestResult", alias="@type")
    result: str

    @staticmethod
    def read(q: dict) -> CustomRequestResult:
        return CustomRequestResult.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject
from ..types import BotCommand


class SetCommands(BaseObject):
    """
    Sets the list of commands supported by the bot; for bots only
    
    Params:
        commands (:obj:`list[BotCommand]`)
            List of the bot's commands
        
    """

    ID: str = Field("setCommands", alias="@type")
    commands: list[BotCommand]

    @staticmethod
    def read(q: dict) -> SetCommands:
        return SetCommands.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class Date(BaseObject):
    """
    Represents a date according to the Gregorian calendar
    
    Params:
        day (:class:`int`)
            Day of the month; 1-31
        
        month (:class:`int`)
            Month; 1-12
        
        year (:class:`int`)
            Year; 1-9999
        
    """

    ID: str = Field("date", alias="@type")
    day: int
    month: int
    year: int

    @staticmethod
    def read(q: dict) -> Date:
        return Date.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class GetFavoriteStickers(BaseObject):
    """
    Returns favorite stickers
    
    """

    ID: str = Field("getFavoriteStickers", alias="@type")

    @staticmethod
    def read(q: dict) -> GetFavoriteStickers:
        return GetFavoriteStickers.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject
from ..types import InputChatPhoto


class SetProfilePhoto(BaseObject):
    """
    Changes a profile photo for the current user
    
    Params:
        photo (:class:`InputChatPhoto`)
            Profile photo to set
        
    """

    ID: str = Field("setProfilePhoto", alias="@type")
    photo: InputChatPhoto

    @staticmethod
    def read(q: dict) -> SetProfilePhoto:
        return SetProfilePhoto.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from .auto_download_settings import AutoDownloadSettings
from ..base_object import BaseObject


class AutoDownloadSettingsPresets(BaseObject):
    """
    Contains auto-download settings presets for the user
    
    Params:
        low (:class:`AutoDownloadSettings`)
            Preset with lowest settings; supposed to be used by default when roaming
        
        medium (:class:`AutoDownloadSettings`)
            Preset with medium settings; supposed to be used by default when using mobile data
        
        high (:class:`AutoDownloadSettings`)
            Preset with highest settings; supposed to be used by default when connected on Wi-Fi
        
    """

    ID: str = Field("autoDownloadSettingsPresets", alias="@type")
    low: AutoDownloadSettings
    medium: AutoDownloadSettings
    high: AutoDownloadSettings

    @staticmethod
    def read(q: dict) -> AutoDownloadSettingsPresets:
        return AutoDownloadSettingsPresets.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class CheckChatUsernameResult(BaseObject):
    """
    Represents result of checking whether a username can be set for a chat
    
    """

    ID: str = Field("checkChatUsernameResult", alias="@type")


class CheckChatUsernameResultOk(CheckChatUsernameResult):
    """
    The username can be set
    
    """

    ID: str = Field("checkChatUsernameResultOk", alias="@type")

    @staticmethod
    def read(q: dict) -> CheckChatUsernameResultOk:
        return CheckChatUsernameResultOk.construct(**q)


class CheckChatUsernameResultPublicChatsTooMuch(CheckChatUsernameResult):
    """
    The user has too much chats with username, one of them should be made private first
    
    """

    ID: str = Field("checkChatUsernameResultPublicChatsTooMuch", alias="@type")

    @staticmethod
    def read(q: dict) -> CheckChatUsernameResultPublicChatsTooMuch:
        return CheckChatUsernameResultPublicChatsTooMuch.construct(**q)


class CheckChatUsernameResultPublicGroupsUnavailable(CheckChatUsernameResult):
    """
    The user can't be a member of a public supergroup
    
    """

    ID: str = Field("checkChatUsernameResultPublicGroupsUnavailable", alias="@type")

    @staticmethod
    def read(q: dict) -> CheckChatUsernameResultPublicGroupsUnavailable:
        return CheckChatUsernameResultPublicGroupsUnavailable.construct(**q)


class CheckChatUsernameResultUsernameInvalid(CheckChatUsernameResult):
    """
    The username is invalid
    
    """

    ID: str = Field("checkChatUsernameResultUsernameInvalid", alias="@type")

    @staticmethod
    def read(q: dict) -> CheckChatUsernameResultUsernameInvalid:
        return CheckChatUsernameResultUsernameInvalid.construct(**q)


class CheckChatUsernameResultUsernameOccupied(CheckChatUsernameResult):
    """
    The username is occupied
    
    """

    ID: str = Field("checkChatUsernameResultUsernameOccupied", alias="@type")

    @staticmethod
    def read(q: dict) -> CheckChatUsernameResultUsernameOccupied:
        return CheckChatUsernameResultUsernameOccupied.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from .language_pack_info import LanguagePackInfo
from ..base_object import BaseObject


class LocalizationTargetInfo(BaseObject):
    """
    Contains information about the current localization target
    
    Params:
        language_packs (:obj:`list[LanguagePackInfo]`)
            List of available language packs for this application
        
    """

    ID: str = Field("localizationTargetInfo", alias="@type")
    language_packs: list[LanguagePackInfo]

    @staticmethod
    def read(q: dict) -> LocalizationTargetInfo:
        return LocalizationTargetInfo.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class AuthenticationCodeType(BaseObject):
    """
    Provides information about the method by which an authentication code is delivered to the user
    
    """

    ID: str = Field("authenticationCodeType", alias="@type")


class AuthenticationCodeTypeCall(AuthenticationCodeType):
    """
    An authentication code is delivered via a phone call to the specified phone number
    
    Params:
        length (:class:`int`)
            Length of the code
        
    """

    ID: str = Field("authenticationCodeTypeCall", alias="@type")
    length: int

    @staticmethod
    def read(q: dict) -> AuthenticationCodeTypeCall:
        return AuthenticationCodeTypeCall.construct(**q)


class AuthenticationCodeTypeFlashCall(AuthenticationCodeType):
    """
    An authentication code is delivered by an immediately cancelled call to the specified phone number. The number from which the call was made is the code
    
    Params:
        pattern (:class:`str`)
            Pattern of the phone number from which the call will be made
        
    """

    ID: str = Field("authenticationCodeTypeFlashCall", alias="@type")
    pattern: str

    @staticmethod
    def read(q: dict) -> AuthenticationCodeTypeFlashCall:
        return AuthenticationCodeTypeFlashCall.construct(**q)


class AuthenticationCodeTypeSms(AuthenticationCodeType):
    """
    An authentication code is delivered via an SMS message to the specified phone number
    
    Params:
        length (:class:`int`)
            Length of the code
        
    """

    ID: str = Field("authenticationCodeTypeSms", alias="@type")
    length: int

    @staticmethod
    def read(q: dict) -> AuthenticationCodeTypeSms:
        return AuthenticationCodeTypeSms.construct(**q)


class AuthenticationCodeTypeTelegramMessage(AuthenticationCodeType):
    """
    An authentication code is delivered via a private Telegram message, which can be viewed from another active session
    
    Params:
        length (:class:`int`)
            Length of the code
        
    """

    ID: str = Field("authenticationCodeTypeTelegramMessage", alias="@type")
    length: int

    @staticmethod
    def read(q: dict) -> AuthenticationCodeTypeTelegramMessage:
        return AuthenticationCodeTypeTelegramMessage.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

import typing

from pydantic import Field

from .invoice import Invoice
from .order_info import OrderInfo
from .shipping_option import ShippingOption
from ..base_object import BaseObject


class PaymentReceipt(BaseObject):
    """
    Contains information about a successful payment
    
    Params:
        date (:class:`int`)
            Point in time (Unix timestamp) when the payment was made
        
        payments_provider_user_id (:class:`int`)
            User identifier of the payment provider bot
        
        invoice (:class:`Invoice`)
            Contains information about the invoice
        
        order_info (:class:`OrderInfo`)
            Contains order information; may be null
        
        shipping_option (:class:`ShippingOption`)
            Chosen shipping option; may be null
        
        credentials_title (:class:`str`)
            Title of the saved credentials
        
    """

    ID: str = Field("paymentReceipt", alias="@type")
    date: int
    payments_provider_user_id: int
    invoice: Invoice
    order_info: typing.Optional[OrderInfo] = None
    shipping_option: typing.Optional[ShippingOption] = None
    credentials_title: str

    @staticmethod
    def read(q: dict) -> PaymentReceipt:
        return PaymentReceipt.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject
from ..types import LanguagePackInfo, LanguagePackString


class SetCustomLanguagePack(BaseObject):
    """
    Adds or changes a custom local language pack to the current localization target
    
    Params:
        info (:class:`LanguagePackInfo`)
            Information about the language pack. Language pack ID must start with 'X', consist only of English letters, digits and hyphens, and must not exceed 64 characters. Can be called before authorization
        
        strings (:obj:`list[LanguagePackString]`)
            Strings of the new language pack
        
    """

    ID: str = Field("setCustomLanguagePack", alias="@type")
    info: LanguagePackInfo
    strings: list[LanguagePackString]

    @staticmethod
    def read(q: dict) -> SetCustomLanguagePack:
        return SetCustomLanguagePack.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class Text(BaseObject):
    """
    Contains some text
    
    Params:
        text (:class:`str`)
            Text
        
    """

    ID: str = Field("text", alias="@type")
    text: str

    @staticmethod
    def read(q: dict) -> Text:
        return Text.construct(**q)
